@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 22309 2013-05-15 07:29:01Z romjerome $
+# $Id: __init__.py 23335 2013-10-18 08:52:28Z romjerome $
 
 """
 Class handling language-specific selection for date parser and displayer.
@@ -33,13 +33,17 @@ import logging
 # import prerequisites for localized handlers
 from _DateHandler import (LANG, LANG_SHORT, LANG_TO_PARSER, LANG_TO_DISPLAY, 
                           register_datehandler)
+                          
+from gen.ggettext import gettext as _
 
 # Import all the localized handlers
+import _Date_ar
 import _Date_bg
 import _Date_ca
 import _Date_cs
 import _Date_da
 import _Date_de
+import _Date_el
 import _Date_es
 import _Date_fi
 import _Date_fr
@@ -55,6 +59,7 @@ import _Date_sk
 import _Date_sl
 import _Date_sr
 import _Date_sv
+import _Date_uk
 
 # Initialize global parser
 try:
