@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: DisplayState.py 22924 2013-08-28 23:32:30Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -273,17 +273,18 @@ class RecentDocsMenu(object):
 
         for item in rfiles:
             try:
-                title = item.get_name().replace('_', '__')
+                title = item.get_name()
                 filename = os.path.basename(item.get_path())
                 action_id = "RecentMenu%d" % count
                 buf.write('<menuitem action="%s"/>' % action_id)
                 actions.append((action_id, None, title, None, None, 
                                 make_callback(item, self.load)))
-                mitem = gtk.MenuItem(title)
+                mitem = gtk.MenuItem(title, use_underline=False)
                 mitem.connect('activate', make_callback(item, self.load))
                 mitem.show()
                 new_menu.append(mitem)
             except RuntimeError:
+                _LOG.info("Ignoring the RecentItem %s (%s)" % (title, filename))
                 pass    # ignore no longer existing files
             
             count += 1
@@ -357,6 +358,7 @@ class DisplayState(gen.utils.Callback):
         'filters-changed' : (str, ), 
         'filter-name-changed' : (str, unicode, unicode), 
         'nameformat-changed' : None, 
+        'update-available' : (list, ), 
         }
     
     #nav_type to message
