@@ -21,7 +21,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: ExportAssistant.py 21270 2013-02-01 17:46:43Z kulath $
 #
 
 # Written by B.Malengier
@@ -357,7 +357,8 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
         filename = filechooser.get_filename()
         folder = filechooser.get_current_folder()
         #the file must be valid, not a folder, and folder must be valid
-        if filename and filename.strip and Utils.find_folder(filename) == '' \
+        if filename and os.path.basename(filename.strip()) \
+                    and Utils.find_folder(filename) == '' \
                     and folder and Utils.find_folder(folder): 
             #this page of the assistant is complete
             self.set_page_complete(filechooser, True)
