@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _MatchesPageSubstringOf.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -40,15 +40,13 @@ from Filters.Rules import Rule
 class MatchesPageSubstringOf(Rule):
     """Citation Volume/Page title containing <substring>"""
 
-    labels      = [ _('Substring:')]
-    name        = _('Citation Volume/Page containing <substring>')
+    labels      = [ _('Text:')]
+    name        = _('Citations with Volume/Page containing <text>')
     description = _("Matches citations whose Volume/Page contains a "
                     "certain substring")
     category    = _('General filters')
+    allow_regex = True
 
     def apply(self, db, object):
         """ Apply the filter """
-        title = object.get_page()
-        if title.upper().find(self.list[0].upper()) != -1:
-            return True
-        return False
+        return self.match_substring(0, object.get_page())
