@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasCitation.py 18554 2011-12-06 16:56:50Z paul-franklin $
+# $Id: _HasCitation.py 22857 2013-08-13 18:23:26Z nick-h $
 
 """
 Filter rule to match event with a particular citation.
@@ -49,13 +49,6 @@ class HasCitation(HasCitationBase):
     labels      = [ _('Volume/Page:'), 
                     _('Date:'), 
                     _('Confidence level:')]
-    name        =  _('Event with the <citation>')
+    name        =  _('Events with the <citation>')
     description = _("Matches events with a citation of a particular "
                     "value")
-    
-    def apply(self, dbase, event):
-        for citation_handle in event.get_citation_list():
-            citation = dbase.get_citation_from_handle(citation_handle)
-            if HasCitationBase.apply(self, dbase, citation):
-                return True
-        return False
