@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: __init__.py 22837 2013-08-09 21:35:05Z nick-h $
 
 """
 Package providing filter rules for GRAMPS.
@@ -47,6 +47,7 @@ from _MatchesSourceFilter import MatchesSourceFilter
 from _HasAttribute import HasAttribute
 from _HasData import HasData
 from _ChangedSince import ChangedSince
+from _MatchesPlaceFilter import MatchesPlaceFilter
 
 editor_rule_list = [
     AllEvents,
@@ -57,7 +58,6 @@ editor_rule_list = [
     HasCitation, 
     HasNote,
     HasNoteRegexp,
-    HasNoteMatchingSubstringOf,
     HasReferenceCountOf,
     HasSourceCount,
     EventPrivate,
@@ -67,5 +67,6 @@ editor_rule_list = [
     MatchesSourceFilter,
     HasAttribute,
     HasData,
-    ChangedSince
+    ChangedSince,
+    MatchesPlaceFilter
 ]
