@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MatchesRegexpOf.py 21974 2013-04-13 14:11:20Z nick-h $
+# $Id: _MatchesRegexpOf.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -42,22 +42,15 @@ from Filters.Rules import Rule
 class MatchesRegexpOf(Rule):
 
     labels      = [ _('Regular expression:')]
-    name        = _('Notes containing <regular expression>')
+    name        = _('Notes containing <text>')
     description = _("Matches notes that contain text "
                     "which matches a regular expression")
     category    = _('General filters')
+    allow_regex = True
 
-    def __init__(self, list, use_regex=False):
-        Rule.__init__(self, list, use_regex)
-        
-        try:
-            self.match = re.compile(list[0], re.I|re.U|re.L)
-        except:
-            self.match = re.compile('')
-            
     def apply(self, db, note):
         """ Apply the filter """
         text = note.get()
-        if self.match.search(text) is not None:
+        if self.match_substring(0, text) is not None:
             return True
         return False
