@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasDeath.py 21941 2013-04-10 13:21:14Z nick-h $
+# $Id: _HasDeath.py 22879 2013-08-19 22:14:11Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -48,9 +48,9 @@ class HasDeath(Rule):
     name        = _('People with the <death data>')
     description = _("Matches people with death data of a particular value")
     category    = _('Event filters')
+    allow_regex = True
     
-    def __init__(self, list, use_regex=False):
-        Rule.__init__(self, list, use_regex)
+    def prepare(self, db):
         if self.list[0]:
             self.date = DateHandler.parser.parse(self.list[0])
         else:
@@ -67,9 +67,7 @@ class HasDeath(Rule):
             if event.get_type() != EventType.DEATH:
                 # No match: wrong type
                 continue
-            ed = event.get_description().upper()
-            if self.list[2] \
-                   and ed.find(self.list[2].upper())==-1:
+            if not self.match_substring(2, event.get_description()):
                 # No match: wrong description
                 continue
             if self.date:
@@ -77,11 +75,10 @@ class HasDeath(Rule):
                     # No match: wrong date
                     continue
             if self.list[1]:
-                pl_id = event.get_place_handle()
-                if pl_id:
-                    pl = db.get_place_from_handle(pl_id)
-                    pn = pl.get_title().upper()
-                    if pn.find(self.list[1].upper()) == -1:
+                place_id = event.get_place_handle()
+                if place_id:
+                    place = db.get_place_from_handle(place_id)
+                    if not self.match_substring(1, place.get_title()):
                         # No match: wrong place
                         continue
                 else:
