@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasSourceOf.py 20270 2012-08-27 09:21:10Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -33,45 +33,17 @@ from gen.ggettext import gettext as _
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from Filters.Rules._Rule import Rule
+from Filters.Rules._HasSourceOfBase import HasSourceOfBase
 
 #-------------------------------------------------------------------------
 #
 # HasSourceOf
 #
 #-------------------------------------------------------------------------
-class HasSourceOf(Rule):
+class HasSourceOf(HasSourceOfBase):
     """Rule that checks people that have a particular source."""
 
     labels      = [ _('Source ID:') ]
     name        = _('People with the <source>')
     category    = _('Citation/source filters')
     description = _('Matches people who have a particular source')
-    
-    def prepare(self,db):
-        if self.list[0] == '':
-            self.source_handle = None
-            self.nosource = True
-            return
-
-        self.nosource = False
-        try:
-            self.source_handle = db.get_source_from_gramps_id(
-                    self.list[0]).get_handle()
-        except:
-            self.source_handle = None
-
-    def apply(self, db, person):
-        if not self.source_handle:
-            if self.nosource:
-                # check whether the citation list is empty as a proxy for
-                # there being no sources
-                return len(person.get_all_citation_lists()) == 0
-            else:
-                return False
-        else:
-            for citation_handle in person.get_all_citation_lists():
-                citation = db.get_citation_from_handle(citation_handle)
-                if citation.get_reference_handle() == self.source_handle:
-                    return True
-            return False
