@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasTextMatchingSubstringOf.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -45,12 +45,12 @@ class HasTextMatchingSubstringOf(Rule):
     """Rule that checks for string matches in any textual information"""
 
     labels      = [ _('Substring:'),
-                    _('Case sensitive:'), 
-                    _('Regular-Expression matching:')]
+                    _('Case sensitive:')]
     name        = _('People with records containing <substring>')
     description = _("Matches people whose records contain text "
                     "matching a substring")
     category    = _('General filters')
+    allow_regex = True
 
     def prepare(self,db):
         self.db = db
@@ -216,6 +216,6 @@ class HasTextMatchingSubstringOf(Rule):
     def match_object(self, obj):
         if not obj:
             return False
-        if self.regexp_match:
+        if self.use_regex:
             return obj.matches_regexp(self.list[0],self.case_sensitive)
         return obj.matches_string(self.list[0],self.case_sensitive)
