@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _RegExpIdOf.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -45,6 +45,6 @@ class RegExpIdOf(RegExpIdBase):
     matches regular expression.
     """
 
-    name        = _('Places with <Id> matching regular expression')
+    name        = _('Places with Id containing <text>')
     description = _("Matches places whose Gramps ID matches "
                     "the regular expression")
