@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasAttributeBase.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -50,6 +50,7 @@ class HasAttributeBase(Rule):
     description = _("Matches objects with the given attribute "
                     "of a particular value")
     category    = _('General filters')
+    allow_regex = True
 
     def apply(self, db, obj):
         if not self.list[0]:
@@ -60,5 +61,5 @@ class HasAttributeBase(Rule):
             name_match = attr.get_type() == specified_type
 
             if name_match:
-                return attr.get_value().upper().find(self.list[1].upper()) != -1
+                return self.match_substring(1, attr.get_value())
         return False
