@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # Filters/Rules/_HasNoteBase.py
-# $Id: _HasNoteBase.py 18361 2011-10-23 03:13:50Z paul-franklin $
+# $Id: _HasNoteBase.py 21941 2013-04-10 13:21:14Z nick-h $
 #
 
 #-------------------------------------------------------------------------
@@ -49,13 +49,13 @@ class HasNoteBase(Rule):
     description = _("Matches objects that have a certain number of notes")
     category    = _('General filters')
 
-    def __init__(self, arg):
+    def __init__(self, arg, use_regex=False):
         # Upgrade from pre 3.1 HasNote filter, use defaults that correspond
         # Previous filter had 0 arguments
         if len(arg) == 0:
-            Rule.__init__(self, ["0", 'greater than'])
+            Rule.__init__(self, ["0", 'greater than'], use_regex)
         else:
-            Rule.__init__(self, arg)
+            Rule.__init__(self, arg, use_regex)
 
     def prepare(self, db):
         # things we want to do just once, not for every handle
