@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasNoteRegexBase.py 21974 2013-04-13 14:11:20Z nick-h $
+# $Id: _HasNoteRegexBase.py 22860 2013-08-13 18:39:18Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -41,25 +41,16 @@ from Filters.Rules import Rule
 class HasNoteRegexBase(Rule):
     """People having notes containing <substring>."""
 
-    labels      = [ _('Regular expression:')]
-    name        = _('Objects having notes containing <regular expression>')
-    description = _("Matches objects whose notes contain text "
-                    "matching a regular expression")
+    labels      = [ _('Text:')]
+    name        = _('Objects having notes containing <text>')
+    description = _("Matches objects whose notes contain a substring "
+                    "or match a regular expression")
     category    = _('General filters')
-
-    def __init__(self, list, use_regex=False):
-        Rule.__init__(self, list, use_regex)
-        
-        try:
-            self.match = re.compile(list[0],re.I|re.U|re.L)
-        except:
-            self.match = re.compile('')
+    allow_regex = True
 
     def apply(self, db, person):
-        notelist = person.get_note_list()
-        for notehandle in notelist:
-            note = db.get_note_from_handle(notehandle)
-            n = note.get()
-            if self.match.search(n) is not None:
+        for handle in person.get_note_list():
+            note = db.get_note_from_handle(handle)
+            if self.match_substring(0, note.get()):
                 return True
         return False
