@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RegExpIdBase.py 21974 2013-04-13 14:11:20Z nick-h $
+# $Id: _RegExpIdBase.py 22837 2013-08-09 21:35:05Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -45,19 +45,12 @@ class RegExpIdBase(Rule):
     Rule that checks for an object whose GRAMPS ID matches regular expression.
     """
 
-    labels      = [ _('Regular expression:') ]
+    labels      = [ _('Text:') ]
     name        = _('Objects with <Id>')
-    description = _("Matches objects whose Gramps ID matches "
-                    "the regular expression")
+    description = _("Matches objects whose Gramps ID contains a substring "
+                    "or matches a regular expression")
     category    = _('General filters')
-
-    def __init__(self, list, use_regex=False):
-        Rule.__init__(self, list, use_regex)
-        
-        try:
-            self.match = re.compile(list[0], re.I|re.U|re.L)
-        except:
-            self.match = re.compile('')
+    allow_regex = True
 
     def apply(self, db, obj):
-        return self.match.search(obj.gramps_id) is not None
+        return self.match_substring(0, obj.gramps_id)
