@@ -19,7 +19,7 @@
 #
 
 # GrampsLogger/_ErrorReportAssistant.py
-# $Id$
+# $Id: _ErrorReportAssistant.py 23171 2013-09-20 11:37:02Z vassilii $
 
 from gen.ggettext import gettext as _
 import Assistant
@@ -39,7 +39,12 @@ else:
 class ErrorReportAssistant(object):
 
     def __init__(self,error_detail,rotate_handler, ownthread=False):
-        self._error_detail = error_detail
+        try:
+            # did we get a handler wrapping the error detail?
+            self._error_detail = error_detail.get_formatted_log()
+        except AttributeError:
+            self._error_detail = error_detail
+
         self._rotate_handler = rotate_handler
 
         self._sys_information_text_buffer = None
@@ -160,8 +165,7 @@ class ErrorReportAssistant(object):
     def _reset_error_details_text_buffer(self, obj=None):
         self._error_details_text_buffer.set_text(
             "\n".join(self._rotate_handler.get_formatted_log(
-                        self._error_detail.get_record()))
-            + self._error_detail.get_formatted_log())
+                        self._error_detail)))
 
     def _clear_error_details_text_buffer(self, obj=None):
         self._error_details_text_buffer.delete(
