@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: mergecitation.py 22972 2013-08-30 23:06:06Z vassilii $
 
 """
 Provide merge capabilities for citations.
@@ -30,7 +30,8 @@ Provide merge capabilities for citations.
 # Gramps modules
 #
 #-------------------------------------------------------------------------
-from gen.lib import (Person, Family, Event, Place, MediaObject, Repository)
+from gen.lib import (Person, Family, Event, Place, 
+    MediaObject, Repository, Citation, Source)
 from gen.db import DbTxn
 from gen.ggettext import sgettext as _
 import const
@@ -225,6 +226,18 @@ class MergeCitationQuery(object):
                     repository.replace_citation_references(old_handle, 
                                                            new_handle)
                     self.database.commit_repository(repository, trans)
+                elif class_name == Citation.__name__:
+                    citation = self.database.get_citation_from_handle(handle)
+                    assert(citation.has_citation_reference(old_handle))
+                    citation.replace_citation_references(old_handle, 
+                                                           new_handle)
+                    self.database.commit_citation(citation, trans)
+                elif class_name == Source.__name__:
+                    source = self.database.get_source_from_handle(handle)
+                    assert(source.has_citation_reference(old_handle))
+                    source.replace_citation_references(old_handle, 
+                                                           new_handle)
+                    self.database.commit_source(source, trans)
                 else:
                     raise MergeError("Encounter an object of type %s that has "
                             "a citation reference." % class_name)
