@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: RecentFiles.py 22773 2013-07-30 14:57:55Z vassilii $
 
 # Written by Alex Roitman
 
@@ -173,8 +173,8 @@ class RecentFiles(object):
             if index > MAX_GRAMPS_ITEMS:
                 break
             xml_file.write('  <RecentItem>\n')
-            xml_file.write('    <Path>%s</Path>\n' % item.get_path())
-            xml_file.write('    <Name>%s</Name>\n' % item.get_name())
+            xml_file.write('    <Path><![CDATA[%s]]></Path>\n' % item.get_path())
+            xml_file.write('    <Name><![CDATA[%s]]></Name>\n' % item.get_name())
             xml_file.write('    <Timestamp>%d</Timestamp>\n' % item.get_time())
             xml_file.write('  </RecentItem>\n')
         xml_file.write('</RecentFiles>\n')
