@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: Spell.py 23222 2013-09-30 12:43:09Z nick-h $
 
 """
 Provide an interface to the gtkspell interface. This requires
@@ -56,9 +56,6 @@ try:
 except ImportError:
     HAVE_GTKSPELL = False
 
-if not HAVE_GTKSPELL:
-    LOG.warn(_("Spelling checker is not installed"))
-
 #-------------------------------------------------------------------------
 #
 # GRAMPS classes
