@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TransUtils.py 20675 2012-11-17 21:28:51Z paul-franklin $
+# $Id: TransUtils.py 22878 2013-08-19 21:23:17Z jralls $
 
 """
 Provide translation assistance
@@ -85,6 +85,10 @@ else:
                 logging.warning('Unable to determine your Locale, using English')
                 lang = 'en.UTF-8'
 
+    _lang_ = lang.replace('@', '.').split('.')
+    if not (len(_lang_) == 2 and _lang_[1] == 'UTF-8'):
+        lang = _lang_[0] + '.UTF-8'
+
     os.environ["LANG"] = lang
     os.environ["LANGUAGE"] = lang
 
