@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Utils.py 22149 2013-05-03 06:55:58Z romjerome $
+# $Id: Utils.py 23140 2013-09-16 18:01:12Z dsblank $
 
 """
 Non GUI/GTK related utility functions
@@ -599,8 +599,12 @@ class ProbablyAlive(object):
         if death_ref and death_ref.get_role().is_primary():
             if death_ref:
                 death = self.db.get_event_from_handle(death_ref.ref)
-                if death and death.get_date_object().get_start_date() != gen.lib.Date.EMPTY:
-                    death_date = death.get_date_object()
+                if death:
+                    if death.get_date_object().is_valid():
+                        death_date = death.get_date_object()
+                    else:
+                        death_date = gen.lib.date.Today()
+                        death_date.set_modifier(gen.lib.Date.MOD_BEFORE)
 
         # Look for Cause Of Death, Burial or Cremation events.
         # These are fairly good indications that someone's not alive.
@@ -610,7 +614,9 @@ class ProbablyAlive(object):
                     ev = self.db.get_event_from_handle(ev_ref.ref)
                     if ev and ev.type.is_death_fallback():
                         death_date = ev.get_date_object()
-                        explain = _("death-related evidence")
+                        if not death_date.is_valid():
+                            death_date = gen.lib.date.Today() # before today
+                            death_date.set_modifier(Date.MOD_BEFORE)
 
         # If they were born within X years before current year then
         # assume they are alive (we already know they are not dead).
@@ -627,7 +633,6 @@ class ProbablyAlive(object):
                 ev = self.db.get_event_from_handle(ev_ref.ref)
                 if ev and ev.type.is_birth_fallback():
                     birth_date = ev.get_date_object()
-                    explain = _("birth-related evidence")
 
         if not birth_date and death_date:
             # person died more than MAX after current year
@@ -825,13 +830,15 @@ class ProbablyAlive(object):
             date1, date2, explain, other = descendants_too_old(person, self.AVG_GENERATION_GAP)
         except RuntimeError:
             raise Errors.DatabaseError(
-                _("Database error: %s is defined as his or her own ancestor") %
+                _("Database error: loop in %s's descendants") %
                 name_displayer.display(person))
 
         if date1 and date2:
             return (date1, date2, explain, other)
 
         def ancestors_too_old(person, year):
+            LOG.debug("ancestors_too_old('{}', {})".format(
+                name_displayer.display(person), year) )
             family_handle = person.get_main_parents_family_handle()
             if family_handle:                
                 family = self.db.get_family_from_handle(family_handle)
@@ -933,9 +940,14 @@ class ProbablyAlive(object):
 
             return (None, None, "", None)
 
-        # If there are ancestors that would be too old in the current year
-        # then assume our person must be dead too.
-        date1, date2, explain, other = ancestors_too_old (person, - self.AVG_GENERATION_GAP)
+        try:
+            # If there are ancestors that would be too old in the current year
+            # then assume our person must be dead too.
+            date1, date2, explain, other = ancestors_too_old (person, - self.AVG_GENERATION_GAP)
+        except RuntimeError:
+            raise Errors.DatabaseError(
+                _("Database error: loop in %s's ancestors") %
+                name_displayer.display(person))
         if date1 and date2:
             return (date1, date2, explain, other)
 
@@ -970,19 +982,17 @@ def probably_alive(person, db,
     :param max_age_prob_alive: maximum age of a person, in years
     :param avg_generation_gap: average generation gap, in years
     """
-    # First, get the real database to use all people
-    # for determining alive status:
-    basedb = db.basedb
-    # Now, we create a wrapper for doing work:
-    pb = ProbablyAlive(basedb, max_sib_age_diff, 
-                       max_age_prob_alive, 
-                       avg_generation_gap)
-    birth, death, explain, relative = pb.probably_alive_range(person)
+    birth, death, explain, relative = probably_alive_range(person, db,
+            max_sib_age_diff, max_age_prob_alive, avg_generation_gap)
     if current_date is None:
         current_date = gen.lib.date.Today()
+    LOG.debug("{}: b.{}, d.{} - {}".format(
+        " ".join(person.get_primary_name().get_text_data_list()),
+        birth, death, explain))
     if not birth or not death:
         # no evidence, must consider alive
-        return (True, None, None, _("no evidence"), None)
+        return ((True, None, None, _("no evidence"), None) if return_range
+                else True)
     # must have dates from here:
     if limit:
         death += limit # add these years to death
@@ -1173,9 +1183,7 @@ def rm_tempdir(path):
         shutil.rmtree(path)
 
 def cast_to_bool(val):
-    if val == str(True):
-        return True
-    return False
+    return val in ['True', 'true', _('True'), _('true'), '1'] # 3139
 
 def get_type_converter(val):
     """
