@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: clidbman.py 21850 2013-04-02 16:01:50Z kulath $
+# $Id: clidbman.py 22867 2013-08-14 20:43:49Z vassilii $
 
 """
 Provide the management of databases from CLI. This includes opening, renaming,
@@ -317,23 +317,25 @@ class CLIDbManager(object):
                  or (None, None) if no import was performed.
         """
         pmgr = BasePluginManager.get_instance()
-        # Allow URL names here; make temp file if necessary
-        url = urlparse.urlparse(filename)
-        if url.scheme != "":
-            if url.scheme == "file":
-                filename = urllib2.url2pathname(filename[7:])
-            else:
-                url_fp = urllib2.urlopen(filename) # open URL
-                # make a temp local file:
-                ext = os.path.splitext(url.path)[1]
-                fd, filename = tempfile.mkstemp(suffix=ext)
-                temp_fp = os.fdopen(fd, "w")
-                # read from URL:
-                data = url_fp.read()
-                # write locally:
-                temp_fp.write(data)
-                url_fp.close()
-                temp_fp.close()
+        # check to see if it isn't a filename directly:
+        if not os.path.isfile(filename):
+            # Allow URL names here; make temp file if necessary
+            url = urlparse.urlparse(filename)
+            if url.scheme != "":
+                if url.scheme == "file":
+                    filename = urllib2.url2pathname(filename[7:])
+                else:
+                    url_fp = urllib2.urlopen(filename) # open URL
+                    # make a temp local file:
+                    ext = os.path.splitext(url.path)[1]
+                    fd, filename = tempfile.mkstemp(suffix=ext)
+                    temp_fp = os.fdopen(fd, "w")
+                    # read from URL:
+                    data = url_fp.read()
+                    # write locally:
+                    temp_fp.write(data)
+                    url_fp.close()
+                    temp_fp.close()
 
         (name, ext) = os.path.splitext(os.path.basename(filename))
         format = ext[1:].lower()
@@ -347,11 +349,7 @@ class CLIDbManager(object):
                 self.__start_cursor(_("Importing data..."))
                 dbclass = gen.db.DbBsddb
                 dbase = dbclass()
-                from  gen.db.dbconst import BDBVERSFN
-                versionpath = os.path.join(name, BDBVERSFN)
-                _LOG.debug("Write bsddb version %s" % str(dbase.version()))
-                with open(versionpath, "w") as version_file:
-                    version_file.write(str(dbase.version()))
+                dbase.write_version(new_path)
                 dbase.load(new_path, callback)
     
                 import_function = plugin.get_import_function()
