@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: base.py 20277 2012-08-28 17:41:05Z romjerome $
+# $Id: base.py 21850 2013-04-02 16:01:50Z kulath $
 
 """
 Base class for the GRAMPS databases. All database interfaces should inherit
@@ -1014,7 +1014,8 @@ class DbReadBase(object):
         """
         raise NotImplementedError
 
-    def load(self, name, callback, mode=None, upgrade=False):
+    def load(self, name, callback, mode=None, force_schema_upgrade=False,
+             force_bsddb_upgrade=False):
         """
         Open the specified database.
         """
@@ -1399,7 +1400,7 @@ class DbWriteBase(DbReadBase):
         """
         raise NotImplementedError
 
-    def need_upgrade(self):
+    def need_schema_upgrade(self):
         """
         Return True if database needs to be upgraded
         """
