@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: citation.py 22965 2013-08-30 19:41:29Z vassilii $
 
 """
 Citation object for GRAMPS.
@@ -43,13 +43,15 @@ from gen.lib.primaryobj import PrimaryObject
 from gen.lib.mediabase import MediaBase
 from gen.lib.notebase import NoteBase
 from gen.lib.datebase import DateBase
+from gen.lib.citationbase import IndirectCitationBase
 
 #-------------------------------------------------------------------------
 #
 # Citation class
 #
 #-------------------------------------------------------------------------
-class Citation(MediaBase, NoteBase, PrimaryObject, DateBase):
+class Citation(MediaBase, NoteBase, IndirectCitationBase, 
+        PrimaryObject, DateBase):
     """
     A record of a citation of a source of information.
     
@@ -192,6 +194,16 @@ class Citation(MediaBase, NoteBase, PrimaryObject, DateBase):
         """
         return self.media_list
 
+    def get_citation_child_list(self):
+        """
+        Return the list of child secondary objects that may refer citations.
+
+        :returns: Returns the list of child secondary child objects that may 
+                refer citations.
+        :rtype: list
+        """
+        return self.media_list
+
     def get_handle_referents(self):
         """
         Return the list of child objects which may, directly or through
