@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: graphdoc.py 21632 2013-03-12 16:33:50Z nick-h $
+# $Id: graphdoc.py 22731 2013-07-24 16:26:44Z paul-franklin $
 
 #------------------------------------------------------------------------
 #
@@ -699,7 +699,7 @@ class GVSvgDoc(GVDocBase):
         fname = self._filename.encode(sys.getfilesystemencoding())
 
         # Generate the SVG file.
-        os.system( 'dot -Tsvg -o"%s" "%s"' % (fname, tmp_dot) )
+        os.system( 'dot -Tsvg:cairo -o"%s" "%s"' % (fname, tmp_dot) )
         
         # Delete the temporary dot file
         os.remove(tmp_dot)
