@@ -17,6 +17,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+# gen/plug/menu/__init__.py
+# $Id: __init__.py 18361 2011-10-23 03:13:50Z paul-franklin $
+#
 """
 The menu package for allowing plugins to specify options in a generic way.
 """
@@ -39,3 +42,4 @@ from _placelist import PlaceListOption
 from _surnamecolor import SurnameColorOption
 from _destination import DestinationOption
 from _style import StyleOption
+from _booleanlist import BooleanListOption
