@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: living.py 20024 2012-07-18 05:18:02Z dsblank $
+# $Id: living.py 23089 2013-09-12 00:49:15Z dsblank $
 
 """
 Proxy class for the GRAMPS databases. Filter out all living people.
@@ -112,10 +112,11 @@ class LivingProxyDb(ProxyDbBase):
         Protected version of iter_people
         """
         for person in ifilter(None, self.db.iter_people()):
-            if not(self.__is_living(person) and
-                   self.mode == self.MODE_EXCLUDE_ALL):
-
-                yield self.__restrict_person(person)
+            if self.__is_living(person):
+                if self.mode == self.MODE_EXCLUDE_ALL: 
+                    continue
+                else:
+                    yield self.__restrict_person(person)
             else:
                 yield person
 
