@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: configure.py 22157 2013-05-04 06:06:16Z romjerome $
+# $Id: configure.py 23222 2013-09-30 12:43:09Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -58,6 +58,10 @@ import ManagedWindow
 from gui.widgets import MarkupLabel, BasicLabel
 from QuestionDialog import ErrorDialog, QuestionDialog2, OkDialog
 from glade import Glade
+from gen.plug.utils import available_updates
+from gui.plug import PluginWindows
+from Errors import WindowActiveError
+from Spell import HAVE_GTKSPELL
 
 #-------------------------------------------------------------------------
 #
@@ -280,6 +284,7 @@ class ConfigureDialog(ManagedWindow.ManagedWindow):
         if extra_callback:
             checkbox.connect('toggled', extra_callback)
         table.attach(checkbox, start, stop, index, index+1, yoptions=0)
+        return checkbox
 
     def add_radiobox(self, table, label, index, constant, group, column,
                      config=None):
@@ -1083,9 +1088,12 @@ class GrampsPreferences(ConfigureDialog):
         self.add_checkbox(table, 
                 _('Add default source on import'), 
                 0, 'preferences.default-source')
-        self.add_checkbox(table, 
+        obj = self.add_checkbox(table, 
                 _('Enable spelling checker'), 
                 1, 'behavior.spellcheck')
+        if not HAVE_GTKSPELL:
+            obj.set_sensitive(False)
+            obj.set_tooltip_text(_("Spelling checker is not installed"))
         self.add_checkbox(table, 
                 _('Display Tip of the Day'), 
                 2, 'behavior.use-tips')
@@ -1142,12 +1150,39 @@ class GrampsPreferences(ConfigureDialog):
 
         table.attach(checkbutton, 1, 2, 9, 10, yoptions=0)
         button = gtk.Button(_("Check now"))
-        button.connect("clicked", lambda obj: \
-                  self.uistate.viewmanager.check_for_updates(force=True))
+        button.connect("clicked", self.check_for_updates)
         table.attach(button, 3, 4, 9, 10, yoptions=0)
 
         return _('General'), table
 
+    def check_for_updates(self, button):
+        try:
+            addon_update_list = available_updates()
+        except:
+            OkDialog(_("Checking Addons Failed"),
+                     _("The addon repository appears to be unavailable. "
+                       "Please try again later."),
+                     self.window)
+            return
+
+        if len(addon_update_list) > 0:
+            try:
+                PluginWindows.UpdateAddons(self.uistate, [], addon_update_list)
+            except WindowActiveError:
+                pass
+        else:
+            check_types = config.get('behavior.check-for-update-types')
+            OkDialog(_("There are no available addons of this type"),
+                     _("Checked for '%s'") %
+                     _("' and '").join([_(t) for t in check_types]),
+                     self.window)
+
+        # List of translated strings used here
+        # Dead code for l10n
+        _('new'), _('update')
+
+        self.uistate.viewmanager.do_reg_plugins(self.dbstate, self.uistate)
+
     def add_famtree_panel(self, configdialog):
         table = gtk.Table(2, 2)
         table.set_border_width(12)
