@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: dbloader.py 22241 2013-05-10 14:29:47Z kulath $
 
 """
 Handling of loading new/existing databases.
@@ -295,29 +295,89 @@ class DbLoader(CLIDbLoader):
 
         self._begin_progress()
         
+        force_schema_upgrade = False
+        force_bsddb_upgrade = False
+        force_bsddb_downgrade = False
+        force_python_upgrade = False
         try:
-            try:
-                self.dbstate.db.load(filename, self._pulse_progress, 
-                                     mode, upgrade=False)
-            except gen.db.exceptions.DbUpgradeRequiredError, msg:
-                if QuestionDialog2(_("Need to upgrade database!"), 
-                                   str(msg), 
-                                   _("Upgrade now"), 
-                                   _("Cancel")).run():
+            while True:
+                try:
                     self.dbstate.db.load(filename, self._pulse_progress, 
-                                         mode, upgrade=True)
+                                         mode, force_schema_upgrade,
+                                         force_bsddb_upgrade,
+                                         force_bsddb_downgrade,
+                                         force_python_upgrade)
                     self.dbstate.db.set_save_path(filename)
-                else:
-                    self.dbstate.no_database()
+                    break
+                except gen.db.exceptions.DbUpgradeRequiredError, msg:
+                    if QuestionDialog2(_("Are you sure you want to upgrade "
+                                         "this Family Tree?"), 
+                                       str(msg), 
+                                       _("I have made a backup,\n"
+                                         "please upgrade my Family Tree"), 
+                                       _("Cancel"), self.uistate.window).run():
+                        force_schema_upgrade = True
+                        force_bsddb_upgrade = False
+                        force_bsddb_downgrade = False
+                        force_python_upgrade = False
+                    else:
+                        self.dbstate.no_database()
+                        break
+                except gen.db.exceptions.BsddbUpgradeRequiredError, msg:
+                    if QuestionDialog2(_("Are you sure you want to upgrade "
+                                         "this Family Tree?"), 
+                                       str(msg), 
+                                       _("I have made a backup,\n"
+                                         "please upgrade my Family Tree"), 
+                                       _("Cancel"), self.uistate.window).run():
+                        force_schema_upgrade = False
+                        force_bsddb_upgrade = True
+                        force_bsddb_downgrade = False
+                        force_python_upgrade = False
+                    else:
+                        self.dbstate.no_database()
+                        break
+                except gen.db.exceptions.BsddbDowngradeRequiredError, msg:
+                    if QuestionDialog2(_("Are you sure you want to downgrade "
+                                         "this Family Tree?"), 
+                                       str(msg), 
+                                       _("I have made a backup,\n"
+                                         "please downgrade my Family Tree"), 
+                                       _("Cancel"), self.uistate.window).run():
+                        force_schema_upgrade = False
+                        force_bsddb_upgrade = False
+                        force_bsddb_downgrade = True
+                        force_python_upgrade = False
+                    else:
+                        self.dbstate.no_database()
+                        break
+                except gen.db.exceptions.PythonUpgradeRequiredError, msg:
+                    if QuestionDialog2(_("Are you sure you want to upgrade "
+                                         "this Family Tree?"), 
+                                       str(msg), 
+                                       _("I have made a backup,\n"
+                                         "please upgrade my Family Tree"), 
+                                       _("Cancel"), self.uistate.window).run():
+                        force_schema_upgrade = False
+                        force_bsddb_upgrade = False
+                        force_bsddb_downgrade = False
+                        force_python_upgrade = True
+                    else:
+                        self.dbstate.no_database()
+                        break
+        # Get here is there is an exception the while loop does not handle
         except gen.db.exceptions.BsddbDowngradeError, msg:
             self.dbstate.no_database()
-            self._errordialog( _("Cannot open database"), str(msg))
+            self._warn( _("Cannot open database"), str(msg))
         except gen.db.exceptions.DbVersionError, msg:
             self.dbstate.no_database()
             self._errordialog( _("Cannot open database"), str(msg))
         except gen.db.exceptions.DbEnvironmentError, msg:
             self.dbstate.no_database()
             self._errordialog( _("Cannot open database"), str(msg))
+        except gen.db.exceptions.PythonDowngradeError, msg:
+            self.dbstate.no_database()
+            self._warn( _("Cannot open database"), str(msg))
         except OSError, msg:
             self.dbstate.no_database()
             self._errordialog(
