@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbman.py 18728 2012-01-09 18:06:11Z m_d_n $
+# $Id: dbman.py 18747 2012-01-15 21:03:51Z m_d_n $
 
 """
 Provide the management of databases. This includes opening, renaming,
@@ -36,6 +36,7 @@ import os
 import time
 import copy
 import subprocess
+import urlparse
 from gen.ggettext import gettext as _
 #-------------------------------------------------------------------------
 #
@@ -648,7 +649,7 @@ class DbManager(CLIDbManager):
         if not prompt:
             return
         
-        opened = store[node][5]
+        opened = store[node][OPEN_COL]
         if opened:
             self.dbstate.no_database()
         
@@ -735,13 +736,13 @@ class DbManager(CLIDbManager):
         fname = None
         type = None
         title = None
-        # we are only interested in this if it is a file:// URL.
-        if drag_value and drag_value[0:7] == "file://":
-
-            drag_value = drag_value.strip()
-
-            fname, title = self.import_new_db(drag_value[7:], None)
-
+        # Allow any type of URL ("file://", "http://", etc):
+        if drag_value and urlparse.urlparse(drag_value).scheme != "":
+            fname, title = [], []
+            for treename in [v.strip() for v in drag_value.split("\n") if v.strip() != '']:
+                f, t = self.import_new_db(treename, None)
+                fname.append(f)
+                title.append(t)
         return fname, title
 
 def drag_motion(wid, context, xpos, ypos, time_stamp):
