@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: embeddedlist.py 18696 2012-01-03 21:00:13Z m_d_n $
+# $Id: embeddedlist.py 19753 2012-06-04 00:55:10Z jralls $
 
 #-------------------------------------------------------------------------
 #
@@ -43,6 +43,7 @@ import pango
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
+import gui.utils
 from buttontab import ButtonTab
 
 #-------------------------------------------------------------------------
@@ -97,7 +98,7 @@ class EmbeddedList(ButtonTab):
         """
         Handle button press, not double-click, that is done in init_interface
         """
-        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+        if gui.utils.is_right_click(event):
             ref = self.get_selected()
             if ref:
                 self.right_click(obj, event)
