@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gallerytab.py 19753 2012-06-04 00:55:10Z jralls $
+# $Id: gallerytab.py 23268 2013-10-08 01:00:55Z dsblank $
 
 #-------------------------------------------------------------------------
 #
@@ -148,6 +148,14 @@ class GalleryTab(ButtonTab, DbGUIElement):
             item = gtk.SeparatorMenuItem()
             item.show()
             menu.append(item)
+
+            item = gtk.MenuItem(_('Make Active Media'))
+            item.connect('activate', lambda obj: self.uistate.set_active(ref_obj.handle, "Media"))
+            item.show()
+            menu.append(item)
+            item = gtk.SeparatorMenuItem()
+            item.show()
+            menu.append(item)
         
         for (needs_write_access, image, title, func) in itemlist:
             if image:
