@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: locationembedlist.py 16063 2010-10-27 18:13:53Z nick-h $
+# $Id: locationembedlist.py 18696 2012-01-03 21:00:13Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -26,6 +26,7 @@
 #
 #-------------------------------------------------------------------------
 from gen.ggettext import gettext as _
+import gobject
 
 #-------------------------------------------------------------------------
 #
@@ -81,8 +82,10 @@ class LocationEmbedList(EmbeddedList):
             pass
 
     def add_callback(self, name):
-        self.get_data().append(name)
+        data = self.get_data()
+        data.append(name)
         self.rebuild()
+        gobject.idle_add(self.tree.scroll_to_cell, len(data) - 1)
 
     def edit_button_clicked(self, obj):
         loc = self.get_selected()
