@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editperson.py 19753 2012-06-04 00:55:10Z jralls $
+# $Id: editperson.py 20925 2013-01-01 14:21:46Z dsblank $
 
 """
 EditPerson Dialog. Provide the interface to allow the GRAMPS program
@@ -610,7 +610,7 @@ class EditPerson(EditPrimary):
         menu.set_title(_("Media Object"))
         obj = self.db.get_object_from_handle(photo.get_reference_handle())
         if obj:
-            gui.utilsadd_menuitem(menu, _("View"), photo,
+            gui.utils.add_menuitem(menu, _("View"), photo,
                                   self._popup_view_photo)
         gui.utils.add_menuitem(menu, _("Edit Object Properties"), photo,
                                self._popup_change_description)
