@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: filtereditor.py 21933 2013-04-09 13:51:07Z nick-h $
+# $Id: filtereditor.py 22903 2013-08-22 17:12:27Z nick-h $
 
 """
 Custom Filter Editor tool.
@@ -68,6 +68,7 @@ import AutoComp
 from gui.selectors import SelectorFactory
 from gen.display.name import displayer as _nd
 import Utils
+from gui.widgets import DateEntry
 
 #-------------------------------------------------------------------------
 #
@@ -532,6 +533,8 @@ class EditRule(ManagedWindow.ManagedWindow):
                     t = MyFilters(self.filterdb.get_filters('Source'))
                 elif v == _('Repository filter name:'):
                     t = MyFilters(self.filterdb.get_filters('Repository'))
+                elif v == _('Place filter name:'):
+                    t = MyFilters(self.filterdb.get_filters('Place'))
                 elif v in _name2typeclass:
                     t = MySelect(_name2typeclass[v])
                 elif v == _('Inclusive:'):
@@ -550,6 +553,8 @@ class EditRule(ManagedWindow.ManagedWindow):
                 elif v == _('Confidence level:'):
                     t = MyList(map(str, range(5)), 
                                [Utils.confidence[i] for i in range(5)])
+                elif v == _('Date:'):
+                    t = DateEntry(self.uistate, self.track)
                 else:                    
                     t = MyEntry()
                 tlist.append(t)
