@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2007  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
+# Copyright (C) 2012-2013  Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _docreportdialog.py 21427 2013-02-24 08:39:34Z paul-franklin $
+# $Id: _docreportdialog.py 22357 2013-05-17 16:10:53Z paul-franklin $
 
 #-------------------------------------------------------------------------
 #
@@ -76,7 +77,7 @@ class DocReportDialog(ReportDialog):
 
     def init_interface(self):
         ReportDialog.init_interface(self)
-        self.doc_type_changed(self.format_menu)
+        self.doc_type_changed(self.format_menu, preserve_tab=False)
 
     #------------------------------------------------------------------------
     #
@@ -102,7 +103,7 @@ class DocReportDialog(ReportDialog):
         
         self.options.set_document(self.doc)
 
-    def doc_type_changed(self, obj):
+    def doc_type_changed(self, obj, preserve_tab=True):
         """This routine is called when the user selects a new file
         formats for the report.  It adjust the various dialog sections
         to reflect the appropriate values for the currently selected
@@ -118,6 +119,7 @@ class DocReportDialog(ReportDialog):
         # Is this to be a printed report or an electronic report
         # (i.e. a set of web pages)
 
+        old_page = self.notebook.get_current_page()
         if self.firstpage_added:
             self.notebook.remove_page(0)
         if docgen_plugin.get_paper_used():
@@ -130,6 +132,8 @@ class DocReportDialog(ReportDialog):
             self.html_label.set_use_markup(True)
             self.notebook.insert_page(self.html_table, self.html_label, 0)
             self.html_table.show_all()
+        if preserve_tab:
+            self.notebook.set_current_page(old_page)
         self.firstpage_added = True
 
         ext_val = docgen_plugin.get_extension()
@@ -176,7 +180,10 @@ class DocReportDialog(ReportDialog):
         else:
             spath = self.get_default_directory()
             default_name = self.dbname + "_" + self.raw_name
-            base = "%s.%s" % (default_name, ext)
+            if self.options.get_output():
+                base = os.path.basename(self.options.get_output())
+            else:
+                base = "%s.%s" % (default_name, ext)
             spath = os.path.normpath(os.path.join(spath, base))
             self.target_fileentry.set_filename(spath)
                 
