@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: selectcitation.py 22939 2013-08-29 18:05:25Z kulath $
 
 """
 SelectCitation class for GRAMPS.
@@ -63,7 +63,7 @@ class SelectCitation(BaseSelector):
 
     def get_column_titles(self):
         return [
-            (_('Page'), 350, BaseSelector.TEXT, 0),
+            (_('Source: Title or Citation: Volume/Page'), 350, BaseSelector.TEXT, 0),
             (_('ID'),     75, BaseSelector.TEXT, 1)
             ]
 
