@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: selectorfactory.py 15322 2010-05-05 03:19:54Z dsblank $
+# $Id: selectorfactory.py 18548 2011-12-04 17:09:17Z kulath $
 
 from selectorexceptions import SelectorException
 
@@ -38,6 +39,9 @@ def SelectorFactory(classname):
     elif classname == 'Source':
         from selectsource import SelectSource
         cls = SelectSource
+    elif classname == 'Citation':
+        from selectcitation import SelectCitation
+        cls = SelectCitation
     elif classname in ['MediaObject', 'Media']:
         from selectobject import SelectObject
         cls = SelectObject
