@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: utils.py 21664 2013-03-16 21:47:20Z nick-h $
+# $Id: utils.py 23033 2013-09-04 16:37:22Z jralls $
 
 """
 Utility functions that depend on GUI components or for GUI components
@@ -31,6 +31,8 @@ Utility functions that depend on GUI components or for GUI components
 #-------------------------------------------------------------------------
 import os
 import sys
+import subprocess
+import threading
 from gen.ggettext import gettext as _
 import constfunc
 # gtk is not included here, because this file is currently imported
@@ -42,6 +44,7 @@ import constfunc
 # GNOME/GTK
 #
 #-------------------------------------------------------------------------
+import gobject
 
 #-------------------------------------------------------------------------
 #
@@ -51,6 +54,7 @@ import constfunc
 import gen.lib
 import Errors
 import constfunc
+from gen.plug.utils import available_updates
 
 #-------------------------------------------------------------------------
 #
@@ -324,40 +328,83 @@ class ProgressMeter(object):
 #
 #
 #-------------------------------------------------------------------------
-def open_file_with_default_application( file_path ):
+def display_error_dialog (index, errorstrings):
+    """
+    Display a message box for errors resulting from xdg-open/open
+    """
+    from QuestionDialog import ErrorDialog
+    error = _("The external program failed to launch or experienced an error")
+    if errorstrings:
+        if isinstance(errorstrings, dict):
+            try:
+                error = errorstrings[index]
+            except KeyError:
+                pass
+        else:
+            error = errorstrings
+
+    ErrorDialog(_("Error from external program"), error)
+
+def poll_external (args):
+    """
+    Check the for completion of a task launched with
+    subprocess.Popen().  This function is intended to be passed to
+    GLib.timeout_add_seconds, so the arguments are in a tuple because that
+    function takes only a single data argument.
+
+    @proc the process, returned from subprocess.Popen()
+    @errorstrings a dict of possible response values and the corresponding messages to display.
+    @returns False when the function has completed.
+    """
+    (proc, errorstrings)= args
+    resp = proc.poll()
+    if resp is None:
+        return True
+
+    if resp != 0:
+        display_error_dialog(resp, errorstrings)
+    return False
+
+def open_file_with_default_application(file_name):
     """
     Launch a program to open an arbitrary file. The file will be opened using
     whatever program is configured on the host as the default program for that
     type of file.
 
     @param file_path: The path to the file to be opened.
-        Example: "c:\foo.txt"
+        Example: "c:\\foo.txt"
     @type file_path: string
     @return: nothing
     """
-    from QuestionDialog import ErrorDialog
-    norm_path = os.path.normpath( file_path )
+    errstrings = None
 
+    norm_path = os.path.normpath(file_name)
     if not os.path.exists(norm_path):
-        ErrorDialog(_("Error Opening File"), _("File does not exist"))
+        display_error_dialog(0, _("File does not exist"))
         return
 
     if constfunc.win():
         try:
             os.startfile(norm_path)
         except WindowsError, msg:
-            ErrorDialog(_("Error Opening File"), str(msg))
+            display_error_dialog(0, str(msg))
+
+        return
+
+    if constfunc.mac():
+        utility = '/usr/bin/open'
     else:
-        if constfunc.mac():
-            utility = '/usr/bin/open'
-        else:
-            utility = 'xdg-open'
-        search = os.environ['PATH'].split(':')
-        for lpath in search:
-            prog = os.path.join(lpath, utility)
-            if os.path.isfile(prog):
-                os.spawnvpe(os.P_NOWAIT, prog, [prog, norm_path], os.environ)
-                return
+        utility = 'xdg-open'
+        errstrings = {1:_('Error in command line syntax.'),
+                      2:_('One of the files passed on the command line did not exist.'),
+                      3:_('A required tool could not be found.'),
+                      4:_('The action failed.')}
+
+    proc = subprocess.Popen([utility, norm_path], stderr=subprocess.STDOUT)
+
+    from gobject import timeout_add
+    timeout_add(1000, poll_external, (proc, errstrings))
+    return
 
 def process_pending_events(max_count=10):
     """
@@ -390,3 +437,96 @@ def is_right_click(event):
 
         if event.button == 3:
             return True
+
+def edit_object(dbstate, uistate, reftype, ref):
+    """
+    Invokes the appropriate editor for an object type and given handle.
+    """
+    from gui.editors import (EditEvent, EditPerson, EditFamily, EditSource,
+                             EditPlace, EditMedia, EditRepository,
+                             EditCitation)
+
+    if reftype == 'Person':
+        try:
+            person = dbstate.db.get_person_from_handle(ref)
+            EditPerson(dbstate, uistate, [], person)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'Family':
+        try:
+            family = dbstate.db.get_family_from_handle(ref)
+            EditFamily(dbstate, uistate, [], family)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'Source':
+        try:
+            source = dbstate.db.get_source_from_handle(ref)
+            EditSource(dbstate, uistate, [], source)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'Citation':
+        try:
+            citation = dbstate.db.get_citation_from_handle(ref)
+            EditCitation(dbstate, uistate, [], citation)
+        except Errors.WindowActiveError:
+            """
+            Return the text used when citation cannot be edited
+            """
+            blocked_text = _("Cannot open new citation editor at this time. "
+                             "Either the citation is already being edited, "
+                             "or the associated source is already being "
+                             "edited, and opening a citation editor "
+                             "(which also allows the source "
+                             "to be edited), would create ambiguity "
+                             "by opening two editors on the same source. "
+                             "\n\n"
+                             "To edit the citation, close the source "
+                             "editor and open an editor for the citation "
+                             "alone")
+            
+            from QuestionDialog import WarningDialog
+            WarningDialog(_("Cannot open new citation editor"),
+                          blocked_text)
+    elif reftype == 'Place':
+        try:
+            place = dbstate.db.get_place_from_handle(ref)
+            EditPlace(dbstate, uistate, [], place)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'MediaObject':
+        try:
+            obj = dbstate.db.get_object_from_handle(ref)
+            EditMedia(dbstate, uistate, [], obj)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'Event':
+        try:
+            event = dbstate.db.get_event_from_handle(ref)
+            EditEvent(dbstate, uistate, [], event)
+        except Errors.WindowActiveError:
+            pass
+    elif reftype == 'Repository':
+        try:
+            repo = dbstate.db.get_repository_from_handle(ref)
+            EditRepository(dbstate, uistate, [], repo)
+        except Errors.WindowActiveError:
+            pass
+
+#-------------------------------------------------------------------------
+#
+# AvailableUpdates
+#
+#-------------------------------------------------------------------------
+class AvailableUpdates(threading.Thread):
+    def __init__(self, uistate):
+        threading.Thread.__init__(self)
+        self.uistate = uistate
+        self.addon_update_list = []
+
+    def emit_update_available(self):
+        self.uistate.emit('update-available', (self.addon_update_list, ))
+
+    def run(self):
+        self.addon_update_list = available_updates()
+        if len(self.addon_update_list) > 0:
+            gobject.idle_add(self.emit_update_available)
