@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  021111307  USA
 #
 
-# $Id: tags.py 19343 2012-04-16 16:20:10Z nick-h $
+# $Id: tags.py 19630 2012-05-23 13:21:22Z nick-h $
 """
 Provide tagging functionality.
 """
@@ -550,7 +550,7 @@ class EditTag(object):
         """
         Save the changes made to the tag.
         """
-        self.tag.set_name(self.entry.get_text())
+        self.tag.set_name(unicode(self.entry.get_text()))
         self.tag.set_color(self.color.get_color().to_string())
 
         if not self.tag.get_name():
