@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: citationtreemodel.py 23141 2013-09-16 21:38:16Z kulath $
 
 """
 CitationTreeModel classes for GRAMPS.
@@ -178,7 +178,20 @@ class CitationTreeModel(CitationBaseModel, TreeBaseModel):
         data        The object data.
         """
         sort_key = self.sort_func2(data)
+        # If the source for this citation already exists (in the tree model) we
+        # add the citation as a child of the source. Otherwise we add the source
+        # first (because citations don't have any meaning without the associated
+        # source)
         if self.get_node(data[5]):
+            #             parent   child   sortkey   handle
+            self.add_node(data[5], handle, sort_key, handle, secondary=True)
+        else:
+            # add the source node first
+            source_sort_key = self.sort_func(self.map(data[5]))
+            #            parent child    sortkey          handle
+            self.add_node(None, data[5], source_sort_key, data[5])
+            
+            #            parent    child   sortkey   handle
             self.add_node(data[5], handle, sort_key, handle, secondary=True)
 
     def on_get_n_columns(self):
