@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # gui/views/treemodels/treebasemodel.py
-# $Id: treebasemodel.py 21174 2013-01-20 15:10:26Z kulath $
+# $Id: treebasemodel.py 23141 2013-09-16 21:38:16Z kulath $
 #
 
 """
@@ -331,7 +331,10 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.__displayed = 0
 
         self.set_search(search)
-        self.rebuild_data(self.current_filter, skip)
+        if self.has_secondary:
+            self.rebuild_data(self.current_filter, self.current_filter2, skip)
+        else:
+            self.rebuild_data(self.current_filter, skip=skip)
 
         _LOG.debug(self.__class__.__name__ + ' __init__ ' +
                     str(time.clock() - cput) + ' sec')
@@ -350,7 +353,9 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.rebuild_data = None
         self._build_data = None
         self.search = None
+        self.search2 = None
         self.current_filter = None
+        self.current_filter2 = None
         self.clear_cache()
         self.lru_data = None
 
@@ -442,31 +447,56 @@ class TreeBaseModel(gtk.GenericTreeModel):
             if search[0] == 1: # Filter
                 #following is None if no data given in filter sidebar
                 self.search = search[1]
+                if self.has_secondary:
+                    self.search2 = search[1]
+                    _LOG.debug("search2 filter %s %s" % (search[0], search[1]))
                 self._build_data = self._rebuild_filter
             elif search[0] == 0: # Search
                 if search[1]:
                     # we have search[1] = (index, text_unicode, inversion)
                     col, text, inv = search[1]
-                    func = lambda x: self._get_value(x, col) or u""
+                    func = lambda x: self._get_value(x, col, secondary=False) or u""
+                    if self.has_secondary:
+                        func2 = lambda x: self._get_value(x, col, secondary=True) or u""
                     if search[2]:
                         self.search = ExactSearchFilter(func, text, inv)
+                        if self.has_secondary:
+                            self.search2 = ExactSearchFilter(func2, text, inv)
                     else:
                         self.search = SearchFilter(func, text, inv)
+                        if self.has_secondary:
+                            self.search2 = SearchFilter(func2, text, inv)
                 else:
                     self.search = None
+                    if self.has_secondary:
+                        self.search2 = None
+                        _LOG.debug("search2 search with no data")
                 self._build_data = self._rebuild_search
             else: # Fast filter
                 self.search = search[1]
+                if self.has_secondary:
+                    self.search2 = search[2]
+                    _LOG.debug("search2 fast filter")
                 self._build_data = self._rebuild_search
         else:
             self.search = None
+            if self.has_secondary:
+                self.search2 = search[2]
+                _LOG.debug("search2 no search parameter")
             self._build_data = self._rebuild_search
             
         self.current_filter = self.search
+        if self.has_secondary:
+            self.current_filter2 = self.search2
 
-    def rebuild_data(self, data_filter=None, skip=[]):
+    def rebuild_data(self, data_filter=None, data_filter2=None, skip=[]):
         """
         Rebuild the data map.
+        
+        When called externally (from listview), data_filter and data_filter2
+        should be None; set_search will already have been called to establish
+        the filter functions. When called internally (from __init__) both
+        data_filter and data_filter2 will have been set from set_search
         """
         cput = time.clock()
         self.clear_cache()
@@ -476,16 +506,21 @@ class TreeBaseModel(gtk.GenericTreeModel):
             return
 
         self.clear()
-        self._build_data(self.current_filter, skip)
+        if self.has_secondary:
+            self._build_data(self.current_filter, self.current_filter2, skip)
+        else:
+            self._build_data(self.current_filter, None, skip)
 
         self._in_build = False
 
         self.current_filter = data_filter
+        if self.has_secondary:
+            self.current_filter2 = data_filter2
 
         _LOG.debug(self.__class__.__name__ + ' rebuild_data ' +
                     str(time.clock() - cput) + ' sec')
 
-    def _rebuild_search(self, dfilter, skip):
+    def _rebuild_search(self, dfilter, dfilter2, skip):
         """
         Rebuild the data map where a search condition is applied.
         """
@@ -493,12 +528,14 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.__displayed = 0
 
         items = self.number_items()
+        _LOG.debug("rebuild search primary")
         self.__rebuild_search(dfilter, skip, items, 
                               self.gen_cursor, self.add_row)
 
         if self.has_secondary:
+            _LOG.debug("rebuild search secondary")
             items = self.number_items2()
-            self.__rebuild_search(dfilter, skip, items, 
+            self.__rebuild_search(dfilter2, skip, items, 
                                   self.gen_cursor2, self.add_row2)
 
     def __rebuild_search(self, dfilter, skip, items, gen_cursor, add_func):
@@ -520,25 +557,33 @@ class TreeBaseModel(gtk.GenericTreeModel):
                 self.__total += 1
                 if not (handle in skip or (dfilter and not
                                         dfilter.match(handle, self.db))):
+                    _LOG.debug("    add %s %s" % (handle, data))
                     self.__displayed += 1
                     add_func(handle, data)
         if not status.was_cancelled():
             status.end()
 
-    def _rebuild_filter(self, dfilter, skip):
+    def _rebuild_filter(self, dfilter, dfilter2, skip):
         """
         Rebuild the data map where a filter is applied.
         """
         self.__total = 0
         self.__displayed = 0
 
-        items = self.number_items()
-        self.__rebuild_filter(dfilter, skip, items, 
-                              self.gen_cursor, self.map, self.add_row)
-        if self.has_secondary:
-            items = self.number_items2()
+        if not self.has_secondary:
+            # The tree only has primary data
+            items = self.number_items()
+            _LOG.debug("rebuild filter primary")
             self.__rebuild_filter(dfilter, skip, items, 
-                                  self.gen_cursor2, self.map2, self.add_row2)
+                                  self.gen_cursor, self.map, self.add_row)
+        else:
+            # The tree has both primary and secondary data. The navigation type
+            # (navtype) which governs the filters that are offered, is for the
+            # secondary data.
+                items = self.number_items2()
+                _LOG.debug("rebuild filter secondary")
+                self.__rebuild_filter(dfilter2, skip, items, 
+                                      self.gen_cursor2, self.map2, self.add_row2)
             
     def __rebuild_filter(self, dfilter, skip, items, gen_cursor, data_map, 
                          add_func):
@@ -567,11 +612,14 @@ class TreeBaseModel(gtk.GenericTreeModel):
         status.heartbeat()
 
         if dfilter:
+            _LOG.debug("rebuild filter %s" % dfilter)
+            _LOG.debug("    list before filter %s" % handle_list)
             status_filter = progressdlg.LongOpStatus(msg=_("Applying filter"),
                         total_steps=items, interval=items//10)
             pmon.add_op(status_filter)
             handle_list = dfilter.apply(self.db, handle_list, 
                                         cb_progress=status_filter.heartbeat)
+            _LOG.debug("    list after filter %s" % handle_list)
             status_filter.end()
         status.heartbeat()
 
@@ -724,13 +772,14 @@ class TreeBaseModel(gtk.GenericTreeModel):
         if self.get_node(handle) is not None:
             return # row already exists
         cput = time.clock()
-        if not self.search or \
-                (self.search and self.search.match(handle, self.db)):
-            #row needs to be added to the model
-            data = self.map(handle)
-            if data:
+        data = self.map(handle)
+        if data:
+            if not self.search or \
+                    (self.search and self.search.match(handle, self.db)):
                 self.add_row(handle, data)
-            else:
+        else:
+            if not self.search2 or \
+                    (self.search2 and self.search2.match(handle, self.db)):
                 self.add_row2(handle, self.map2(handle))
 
         _LOG.debug(self.__class__.__name__ + ' add_row_by_handle ' +
@@ -845,10 +894,13 @@ class TreeBaseModel(gtk.GenericTreeModel):
             # according to column_defs table
             return self._get_value(node.handle, col, node.secondary)
             
-    def _get_value(self, handle, col, secondary=False):
+    def _get_value(self, handle, col, secondary=None):
         """
         Returns the contents of a given column of a gramps object
         """
+        if secondary is None:
+            raise NotImplementedError
+        
         if handle in self.lru_data:
             data = self.lru_data[handle]
         else:
@@ -856,16 +908,20 @@ class TreeBaseModel(gtk.GenericTreeModel):
                 data = self.map(handle)
             else:
                 data = self.map2(handle)
-        if not self._in_build:
-            self.lru_data[handle] = data
-
-        try:
-            if not secondary:
-                return (self.fmap[col](data))
-            else:
-                return (self.fmap2[col](data))
-        except:
-            return None
+            if not self._in_build:
+                self.lru_data[handle] = data
+                
+        if not secondary:
+            # None is used to indicate this column has no data
+            if self.fmap[col] is None:
+                return None
+            value = self.fmap[col](data)
+        else:
+            if self.fmap2[col] is None:
+                return None
+            value = self.fmap2[col](data)
+            
+        return value
 
     def on_get_iter(self, path):
         """
