@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: grampletpane.py 21709 2013-03-20 14:04:30Z romjerome $
+# $Id: grampletpane.py 23039 2013-09-05 22:46:18Z nick-h $
 
 """
 GrampletView interface.
@@ -97,8 +97,9 @@ def GET_AVAILABLE_GRAMPLETS(name):
     return None
 
 def GET_GRAMPLET_LIST(nav_type, skip):
-    return [(gplug.name, gplug.id) for gplug in PLUGMAN.get_reg_gramplets()
-            if gplug.navtypes == [] or nav_type in gplug.navtypes
+    return [(gplug.gramplet_title, gplug.id)
+            for gplug in PLUGMAN.get_reg_gramplets()
+            if (gplug.navtypes == [] or nav_type in gplug.navtypes)
             and gplug.name not in skip]
 
 def parse_tag_attr(text):
@@ -1232,6 +1233,9 @@ class GrampletPane(gtk.ScrolledWindow):
         mainframe = mframe.get_parent() # actually a vbox
         rect = source.get_allocation()
         sx, sy = rect.width, rect.height
+        # Convert to LTR co-ordinates when using RTL locale
+        if source.get_direction() == gtk.TEXT_DIR_RTL:
+            x = sx - x
         # first, find column:
         col = 0
         for i in range(len(self.columns)):
