@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: monitoredwidgets.py 21651 2013-03-15 16:15:53Z nick-h $
+# $Id: monitoredwidgets.py 22734 2013-07-24 19:11:37Z paul-franklin $
 
 __all__ = ["MonitoredCheckbox", "MonitoredEntry", 
            "MonitoredEntryIndicator", "MonitoredSpinButton",
@@ -554,6 +554,10 @@ class MonitoredStrMenu(object):
         
         if len(mapping) > 20:
             self.obj.set_wrap_width(3)
+        if len(mapping) > 40:
+            self.obj.set_wrap_width(4)
+        if len(mapping) > 100: # currently, there are 153 entries in lds.xml
+            self.obj.set_wrap_width(5)
 
         self.model.append(row=[''])
         index = 0
