@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: Records.py 22662 2013-07-08 21:52:24Z paul-franklin $
 
 #------------------------------------------------------------------------
 #
@@ -288,6 +288,9 @@ def _find_records(db, filter, callname):
 
 def _record(lowest, highest, value, text, handle_type, handle):
 
+    if value < 0: # ignore erroneous data
+        return # (since the data-verification tool already finds it)
+
     if lowest is not None:
         lowest.append((value, text, handle_type, handle))
         lowest.sort(lambda a,b: cmp(a[0], b[0]))        # FIXME: Ist das lambda notwendig?
@@ -306,7 +309,7 @@ def _record(lowest, highest, value, text, handle_type, handle):
 
 
 def _output(value):
-    return str(value)
+    return unicode(value)
 
 
 #------------------------------------------------------------------------
