@@ -6,6 +6,7 @@
 # Copyright (C) 2009-2010  Benny Malengier <benny.malengier@gramps-project.org>
 # Copyright (C) 2010       Peter Landgren
 # Copyright (C) 2010       Tim Lyons
+# Copyright (C) 2011       Adam Stein <adam@csh.rit.edu>
 
 #
 # This program is free software; you can redistribute it and/or modify
@@ -23,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:HtmlDoc.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: HtmlDoc.py 18848 2012-02-10 19:57:57Z nick-h $
 
 
 """
@@ -47,7 +48,7 @@ from gen.ggettext import gettext as _
 #------------------------------------------------------------------------
 import ImgManip
 import const
-from gen.plug.docgen import BaseDoc, TextDoc, FONT_SANS_SERIF
+from gen.plug.docgen import BaseDoc, TextDoc, FONT_SANS_SERIF, URL_PATTERN
 from libhtmlbackend import HtmlBackend, process_spaces
 from libhtml import Html
 
@@ -62,6 +63,13 @@ LOG = logging.getLogger(".htmldoc")
 _TEXTDOCSCREEN = 'grampstextdoc.css'
 _HTMLSCREEN = 'grampshtml.css'
 
+#------------------------------------------------------------------------
+#
+# Set up to make links clickable
+#
+#------------------------------------------------------------------------
+_CLICKABLE = r'''<a href="\1">\1</a>'''
+
 #------------------------------------------------------------------------
 #
 # HtmlDoc
@@ -296,17 +304,21 @@ class HtmlDoc(BaseDoc, TextDoc):
         self.htmllist[-2] += self.htmllist[-1]
         self.htmllist.pop()
     
-    def __write_text(self, text, mark=None, markup=False):
+    def __write_text(self, text, mark=None, markup=False, links=False):
         """
         @param text: text to write.
         @param mark:  IndexMark to use for indexing (if supported)
         @param markup: True if text already contains markup info. 
                        Then text will no longer be escaped
+        @param links: make URLs clickable if True
         """
         if not markup:            
             text = self._backend.ESCAPE_FUNC()(text)
         if self.__title_written == 0 :
             self.title += text
+        if links == True:
+            import re
+            text = re.sub(URL_PATTERN, _CLICKABLE, text)
         self.htmllist[-1] += text
     
     def __empty_char(self):
@@ -316,13 +328,13 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         self.__write_text('&nbsp;', markup=True)
     
-    def write_text(self, text, mark=None):
+    def write_text(self, text, mark=None, links=False):
         """
         Overwrite base method
         """
         if text != "":
             self._empty = 0
-        self.__write_text(text, mark)
+        self.__write_text(text, mark, links=links)
 
     def write_title(self):
         """
@@ -448,24 +460,8 @@ class HtmlDoc(BaseDoc, TextDoc):
         """
         self.__reduce_list()
 
-    def write_endnotes_ref(self, text, style_name):
-        """
-        Overwrite base method for lines of endnotes references
-        """
-        self.htmllist += [Html('div', id='grampsstylednote')]
-        for line in text.split('\n'):
-        #    more basic method we convert all to a monospace character
-            self.htmllist += [Html('pre', class_=style_name, 
-                            style = 'font-family: courier, monospace',
-                            indent=None, inline=True)]
-            self.write_text(line)
-            #end pre element
-            self.__reduce_list()
-        #end div element
-        self.__reduce_list()
-
     def write_styled_note(self, styledtext, format, style_name,
-                          contains_html=False):
+                          contains_html=False, links=False):
         """
         Convenience function to write a styledtext to the html doc. 
         styledtext : assumed a StyledText object to write
@@ -476,6 +472,7 @@ class HtmlDoc(BaseDoc, TextDoc):
             some way. Eg, a textdoc could remove all tags, or could make sure
             a link is clickable. HtmlDoc will show the html as pure text, so 
             no escaping will happen.
+        links: bool, make URLs clickable if True
         """
         text = str(styledtext)
 
@@ -484,7 +481,7 @@ class HtmlDoc(BaseDoc, TextDoc):
             #just dump the note out as it is. Adding markup would be dangerous
             # as it could destroy the html. If html code, one can do the 
             self.start_paragraph(style_name)
-            self.__write_text(text, markup=True)
+            self.__write_text(text, markup=True, links=links)
             self.end_paragraph()
         else:
             s_tags = styledtext.get_tags()
@@ -517,7 +514,7 @@ class HtmlDoc(BaseDoc, TextDoc):
                         self._empty = 1   # para is empty
                     if linenb > 1:
                         self.htmllist[-1] += Html('br')
-                    self.__write_text(line, markup=True)
+                    self.__write_text(line, markup=True, links=links)
                     self._empty = 0  # para is not empty
                     linenb += 1
             if inpara == True:
@@ -532,7 +529,7 @@ class HtmlDoc(BaseDoc, TextDoc):
         #end div element
         self.__reduce_list()
 
-    def add_media_object(self, name, pos, w_cm, h_cm, alt=''):
+    def add_media_object(self, name, pos, w_cm, h_cm, alt='', style_name=None, crop=None):
         """
         Overwrite base method
         """
@@ -543,17 +540,34 @@ class HtmlDoc(BaseDoc, TextDoc):
         imdir = self._backend.datadirfull()
 
         try:
-            ImgManip.resize_to_jpeg(name, imdir + os.sep + refname, size, size)
+            ImgManip.resize_to_jpeg(name, imdir + os.sep + refname, size, size, crop=crop)
         except:
             LOG.warn(_("Could not create jpeg version of image %(name)s") % 
                         {'name' : name})
             return
 
+        if len(alt):
+            alt = '<br />'.join(alt)
+
         if pos not in ["right", "left"] :
-            self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
+            if len(alt):
+                self.htmllist[-1] += Html('div') + (
+                    Html('img', src= imdir + os.sep + refname,
+                         border = '0', alt=alt),
+                    Html('p', class_="DDR-Caption") + alt
+                )
+            else:
+                self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
                             border = '0', alt=alt)
         else:
-            self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
+            if len(alt):
+                self.htmllist[-1] += Html('div', style_="float: %s; padding: 5px; margin: 0;" % pos) + (
+                    Html('img', src= imdir + os.sep + refname,
+                         border = '0', alt=alt),
+                    Html('p', class_="DDR-Caption") + alt
+                )
+            else:
+                self.htmllist[-1] += Html('img', src= imdir + os.sep + refname, 
                             border = '0', alt=alt, align=pos)
 
     def page_break(self):
