@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: RTFDoc.py 22702 2013-07-21 10:59:44Z vassilii $
 
 #------------------------------------------------------------------------
 #
@@ -474,7 +474,6 @@ class RTFDoc(BaseDoc,TextDoc):
     def write_text(self,text,mark=None,links=False):
     # Convert to unicode, just in case it's not. Fix of bug 2449.
         text = unicode(text)
-        text = text.replace('\n','\n\\par ')
         LOG.debug("write_text: opened: %d input text: %s" % 
                   (self.opened, 
                    text))
@@ -489,8 +488,10 @@ class RTFDoc(BaseDoc,TextDoc):
                 else:
                     # If (uni)code with more than 8 bits: 
                     # RTF req valus in decimal, not hex.
-                    self.text += '\\uc1\\u%d\\uc0' % ord(i)
-            elif i == '{' or i == '}' :
+                    self.text += '{\\uc1\\u%d\\uc0}' % ord(i)
+            elif i == '\n':
+                self.text += '\n\\par ';
+            elif i == '{' or i == '}' or i == '\\':
                 self.text += '\\%s' % i
             else:
                 self.text += i
