@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Calendar.py 20817 2012-12-21 18:57:46Z dsblank $
+# $Id: Calendar.py 23212 2013-09-27 23:19:00Z vassilii $
 #
 #------------------------------------------------------------------------
 #
@@ -52,6 +52,7 @@ from Utils import probably_alive
 from DateHandler import displayer as _dd
 import GrampsLocale
 import gen.lib
+from gen.lib.date import gregorian
 
 import libholiday
 from libholiday import g2iso
@@ -280,6 +281,8 @@ class Calendar(Report):
                 birth_date = birth_event.get_date_object()
 
             if (self.birthdays and birth_date is not None and birth_date.is_valid()):
+                birth_date = gregorian(birth_date)
+
                 year = birth_date.get_year()
                 month = birth_date.get_month()
                 day = birth_date.get_day()
@@ -360,6 +363,8 @@ class Calendar(Report):
                                     event_obj = event.get_date_object()
 
                                     if event_obj.is_valid():
+                                        event_obj = gregorian(event_obj)
+
                                         year = event_obj.get_year()
                                         month = event_obj.get_month()
                                         day = event_obj.get_day()
