@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: FanChart.py 20290 2012-08-30 13:16:06Z bmcage $
 
 #------------------------------------------------------------------------
 #
@@ -166,7 +166,7 @@ class FanChart(Report):
 
         self.background_style = []
         self.text_style = []
-        for i in range (0, self.max_generations):
+        for i in range (0, self.max_generations+1):
             if self.background == BACKGROUND_WHITE:
                 background_style_name = 'background_style_white'
             else:
