@@ -24,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExportXml.py 20438 2012-09-23 22:28:34Z kulath $
+# $Id: ExportXml.py 23287 2013-10-09 16:19:30Z paul-franklin $
 
 """
 Contains the interface to allow a database to get written using
@@ -538,7 +538,7 @@ class GrampsXmlWriter(UpdateCallback):
         self.write_note_list(person.get_note_list(),index+1)
 
         for citation_handle in person.get_citation_list():
-            self.write_ref("citationref", citation_handle, index+2)
+            self.write_ref("citationref", citation_handle, index+1)
 
         for tag_handle in person.get_tag_list():
             self.write_ref("tagref", tag_handle, index+1)
@@ -578,7 +578,8 @@ class GrampsXmlWriter(UpdateCallback):
         self.write_primary_tag("citation", citation, index)
         self.write_date(citation.get_date_object(), index+1)
         self.write_line("page", citation.get_page(), index+1)
-        self.write_line("confidence", citation.get_confidence_level(), index+1)
+        self.write_line_always("confidence",
+                               citation.get_confidence_level(), index+1)
         self.write_note_list(citation.get_note_list(), index+1)
         self.write_media_list(citation.get_media_list(), index+1)
         self.write_data_map(citation.get_data_map())
@@ -828,13 +829,18 @@ class GrampsXmlWriter(UpdateCallback):
 
     def write_line_nofix(self,tagname,value,indent=1):
         """Writes a line, but does not escape characters. 
-            Use this instead of write_line is the value is already fixed,
+            Use this instead of write_line if the value is already fixed,
             this avoids &amp; becoming &amp;amp;
         """
         if value:
             self.g.write('%s<%s>%s</%s>\n' %
                          ('  '*indent, tagname, value, tagname))
 
+    def write_line_always(self,tagname,value,indent=1):
+        """Writes a line, always, even with a zero value."""
+        self.g.write('%s<%s>%s</%s>\n' %
+                     ('  '*indent,tagname,self.fix(value),tagname))
+
     def get_iso_date(self,date):
         if date[2] == 0:
             y = "????"
