@@ -17,12 +17,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: Backlinks.py 23265 2013-10-07 22:02:49Z nick-h $
 #
 
 from ListModel import ListModel, NOSORT
 from Utils import navigation_label
 from gen.plug import Gramplet
+from gui.utils import edit_object
 from gen.ggettext import gettext as _
 import gtk
 
@@ -33,7 +34,7 @@ class Backlinks(Gramplet):
     def init(self):
         self.gui.WIDGET = self.build_gui()
         self.gui.get_container_widget().remove(self.gui.textview)
-        self.gui.get_container_widget().add_with_viewport(self.gui.WIDGET)
+        self.gui.get_container_widget().add(self.gui.WIDGET)
         self.gui.WIDGET.show()
 
     def build_gui(self):
@@ -42,8 +43,10 @@ class Backlinks(Gramplet):
         """
         top = gtk.TreeView()
         titles = [(_('Type'), 1, 100),
-                  (_('Name'), 2, 100)]
-        self.model = ListModel(top, titles)
+                  (_('Name'), 2, 100),
+                  ('', 3, 1), #hidden column for the handle
+                  ('', 4, 1)] #hidden column for non-localized object type 
+        self.model = ListModel(top, titles, event_func=self.cb_double_click)
         return top
         
     def display_backlinks(self, active_handle):
@@ -53,7 +56,7 @@ class Backlinks(Gramplet):
         for classname, handle in \
                         self.dbstate.db.find_backlink_handles(active_handle):
             name = navigation_label(self.dbstate.db, classname, handle)[0]
-            self.model.add((_(classname), name))
+            self.model.add((_(classname), name, handle, classname))
         self.set_has_data(self.model.count > 0)
 
     def get_has_data(self, active_handle):
@@ -66,6 +69,19 @@ class Backlinks(Gramplet):
             return True
         return False
         
+    def cb_double_click(self, treeview):
+        """
+        Handle double click on treeview.
+        """
+        (model, iter_) = treeview.get_selection().get_selected()
+        if not iter_:
+            return
+
+        (objclass, handle) = (model.get_value(iter_, 3), 
+                              model.get_value(iter_, 2))
+
+        edit_object(self.dbstate, self.uistate, objclass, handle)
+
 class PersonBacklinks(Backlinks):
     """
     Displays the back references for a person.
