@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Citations.py 21701 2013-03-19 23:14:56Z nick-h $
+# $Id: Citations.py 23265 2013-10-07 22:02:49Z nick-h $
 #
 
 from gui.editors import EditSource, EditCitation
@@ -40,7 +40,7 @@ class Citations(Gramplet, DbGUIElement):
     def init(self):
         self.gui.WIDGET = self.build_gui()
         self.gui.get_container_widget().remove(self.gui.textview)
-        self.gui.get_container_widget().add_with_viewport(self.gui.WIDGET)
+        self.gui.get_container_widget().add(self.gui.WIDGET)
         self.gui.WIDGET.show()
 
     def _connect_db_signals(self):
