@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: PersonResidence.py 23265 2013-10-07 22:02:49Z nick-h $
 #
 
 from gen.lib import EventType, EventRoleType
@@ -35,7 +35,7 @@ class PersonResidence(Gramplet):
     def init(self):
         self.gui.WIDGET = self.build_gui()
         self.gui.get_container_widget().remove(self.gui.textview)
-        self.gui.get_container_widget().add_with_viewport(self.gui.WIDGET)
+        self.gui.get_container_widget().add(self.gui.WIDGET)
         self.gui.WIDGET.show()
 
     def build_gui(self):
