@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gramplet.gpr.py 20028 2012-07-18 17:25:46Z dsblank $
+# $Id: gramplet.gpr.py 22957 2013-08-30 18:08:49Z nick-h $
 
 #------------------------------------------------------------------------
 #
@@ -54,23 +54,6 @@ register(GRAMPLET,
          gramps_target_version="3.4",
          )
 
-register(GRAMPLET, 
-         id="Attributes", 
-         name=_("Attributes"), 
-         description = _("Gramplet showing active person's attributes"),
-         status = STABLE,
-         fname="AttributesGramplet.py",
-         height=150,
-         expand=True,
-         gramplet = 'AttributesGramplet',
-         gramplet_title=_("Attributes"),
-         detached_width = 325,
-         detached_height = 250,
-         version="1.0.0",
-         gramps_target_version="3.4",
-         navtypes=["Person"],
-         )
-
 register(GRAMPLET, 
          id="Calendar", 
          name=_("Calendar"), 
