@@ -24,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libcairodoc.py 22137 2013-05-02 08:50:51Z bmcage $
+# $Id: libcairodoc.py 22803 2013-08-06 17:09:56Z vassilii $
 
 """Report output generator based on Cairo.
 """
@@ -1336,10 +1336,21 @@ class CairoDoc(BaseDoc, TextDoc, DrawDoc):
     """
     
     # BaseDoc implementation
+    EXT = 'pdf' 
     
     def open(self, filename):
-        if filename[-4:] != '.pdf':
-            filename = filename + '.pdf'
+        fe = filename.split('.')
+        if len(fe) == 1:
+            filename = filename + '.' + self.EXT
+        elif fe[-1] != self.EXT:
+            # NOTE: the warning will be bogus 
+            # if the EXT isn't properly overridden by derived class
+            log.warn(_(
+"""Mismatch between selected extension %(ext)s and actual format.
+ Writing to %(filename)s in format %(impliedext)s.""") % 
+                {'ext' : fe[-1], 
+                 'filename' : filename, 
+                 'impliedext' : self.EXT} )
         self._backend = CairoBackend(filename)
         self._doc = GtkDocDocument()
         self._active_element = self._doc
