@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: libgrdb.py 21850 2013-04-02 16:01:50Z kulath $
 
 """
 Base class for the GRAMPS databases before version 3.0.
@@ -287,7 +287,7 @@ class DbGrdb(Callback):
         """Return True when the file has a supported version."""
         return True
 
-    def need_upgrade(self):
+    def need_scema_upgrade(self):
         return False
 
     def gramps_upgrade(self):
