@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: googlemap.py 20632 2012-11-05 09:05:30Z romjerome $
 #
 """
 Google Maps map service plugin. Open place in maps.google.com
@@ -51,7 +51,7 @@ class GoogleMapService(MapService):
         place = self._get_first_place()[0]
         latitude, longitude = self._lat_lon(place)
         if longitude and latitude:
-            self.url = "http://maps.google.com/?sll=%s,%s&z=15" % (latitude, 
+            self.url = "http://maps.google.com/maps/mm?sll=%s,%s&z=15" % (latitude, 
                                                                longitude)
             return
         
