@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: rel_ru.py 22719 2013-07-22 20:44:23Z vassilii $
 
 # Written by Alex Roitman, largely based on Relationship.py by Don Allingham.
 """
@@ -139,7 +139,7 @@ _junior_female_removed_level = [
   ]
 
 _juniors_removed_level = [ 
-  u"братя/сестры", 
+  u"братья/сестры", 
   u"племянники", 
   u"внучатые племянники", 
   u"правнучатые племянники", 
@@ -160,22 +160,22 @@ _senior_male_removed_level = [
 
 _senior_female_removed_level = [ 
   u"", 
-  u"тётка", 
-  u"бабка", 
-  u"прабабка", 
-  u"прапрабабка", 
-  u"прапрапрабабка", 
-  u"прапрапрапрабабка", 
+  u"тётя", 
+  u"бабушка", 
+  u"прабабушка", 
+  u"прапрабабушка", 
+  u"прапрапрабабушка", 
+  u"прапрапрапрабабушка", 
   ]
 
 _seniors_removed_level = [ 
   u"", 
-  u"дядьки/тётки", 
+  u"дяди/тёти", 
   u"дедушки/бабушки", 
   u"прадеды/прабабушки", 
   u"прапрадеды/прапрабабушки", 
   u"прапрапрадеды/прапрапрабабушки", 
-  u"прапрапрапрадеды/прапрапрабабушки", 
+  u"прапрапрапрадеды/прапрапрапрабабушки", 
   ]
 
 _father_level = [ 
@@ -191,11 +191,11 @@ _father_level = [
 _mother_level = [ 
    u"", 
    u"мать", 
-   u"бабка", 
-   u"прабабка", 
-   u"прапрабабка", 
-   u"прапрапрабабка", 
-   u"прапрапрапрабабка", 
+   u"бабушка", 
+   u"прабабушка", 
+   u"прапрабабушка", 
+   u"прапрапрабабушка", 
+   u"прапрапрапрабабушка", 
    ]
 
 _son_level = [ 
@@ -232,12 +232,12 @@ _children_level = [
 _sister_level = [ 
   u"", 
   u"сестра", 
-  u"тётка", 
-  u"двоюродная бабка", 
-  u"двоюродная прабабка", 
-  u"двоюродная прапрабабка", 
-  u"двоюродная прапрапрабабка", 
-  u"двоюродная прапрапрапрабабка", 
+  u"тётя", 
+  u"двоюродная бабушка", 
+  u"двоюродная прабабушка", 
+  u"двоюродная прапрабабушка", 
+  u"двоюродная прапрапрабабушка", 
+  u"двоюродная прапрапрапрабабушка", 
   ]
 
 _brother_level = [ 
@@ -256,7 +256,7 @@ _siblings_level = [
   u"братья/сестры", 
   u"дядьки/тётки", 
   u"двоюродные дедушки/бабушки", 
-  u"двоюродные прадедеды/прабабушки", 
+  u"двоюродные прадедушки/прабабушки", 
   u"двоюродные прапрадедушки/прапрабабушки (5 поколение)", 
   u"двоюродные прапрапрадедушки/прапрапрабабушки (6 поколение)",
   u"двоюродные прапрапрапрадедушки/прапрапрапрабабушки (7 поколение)",
@@ -287,11 +287,11 @@ _nephews_nieces_level = [
   u"", 
   u"братья/сестры", 
   u"племянники", 
-  u"внучатый племянники", 
-  u"правнучатый племянники", 
-  u"праправнучатый племянники", 
-  u"прапраправнучатый племянники", 
-  u"прапрапраправнучатый племянники", 
+  u"внучатые племянники", 
+  u"правнучатые племянники", 
+  u"праправнучатые племянники", 
+  u"прапраправнучатые племянники", 
+  u"прапрапраправнучатые племянники", 
   ]
 
 #-------------------------------------------------------------------------
@@ -367,13 +367,13 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
 
     def _get_aunt(self, level, step='', inlaw=''):
         if level > len(_sister_level)-1:
-            return u"дальний предок"
+            return u"дальний предок в соседнем поколении"
         else:
             return _sister_level[level]
 
     def _get_uncle(self, level, step='', inlaw=''):
         if level > len(_brother_level)-1:
-            return u"дальний предок"
+            return u"дальний предок в соседнем поколении"
         else:
             return _brother_level[level]
 
@@ -381,17 +381,17 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         """
         Sibling of unknown gender
         """
-        return self._get_uncle(level, step, inlaw) + u" или u" + self._get_aunt(level, step, inlaw)
+        return self._get_uncle(level, step, inlaw) + u" или " + self._get_aunt(level, step, inlaw)
 
     def get_nephew(self, level):
         if level > len(_nephew_level)-1:
-            return u"дальний потомок"
+            return u"дальний потомок в соседнем поколении"
         else:
             return _nephew_level[level]
 
     def get_niece(self, level):
         if level > len(_niece_level)-1:
-            return u"дальний потомок"
+            return u"дальний потомок в соседнем поколении"
         else:
             return _niece_level[level]
 
