@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DescendReport.py 18915 2012-02-17 16:51:40Z romjerome $
+# $Id: DescendReport.py 20126 2012-07-29 00:33:21Z ander882 $
 
 """
 Reports/Text Reports/Descendant Report.
@@ -282,7 +282,7 @@ class RecurseDown():
                 # Just print a reference
                 spouse = self.database.get_person_from_handle(spouse_handle)
                 self.objPrint.print_reference(level, spouse,
-                        self.person_printed[person_handle])
+                        self.person_printed[spouse_handle])
             else:
                 self.objPrint.print_spouse(level, spouse_handle, family)
 
