@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: ChangeNames.py 22894 2013-08-21 14:41:12Z vassilii $
 
 """Tools/Database Processing/Fix Capitalization of Family Names"""
 
@@ -78,7 +78,7 @@ class ChangeNames(tool.BatchTool, ManagedWindow.ManagedWindow):
         ManagedWindow.ManagedWindow.__init__(self,uistate,[],self.__class__)
         self.set_window(gtk.Window(),gtk.Label(),'')
 
-        tool.BatchTool.__init__(self, dbstate, options_class, name)
+        tool.BatchTool.__init__(self, dbstate, uistate, options_class, name)
         if self.fail:
             return
 
