@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ChangeTypes.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id: ChangeTypes.py 22894 2013-08-21 14:41:12Z vassilii $
 
 """Database Processing/Rename Event Types"""
 
@@ -56,7 +56,7 @@ class ChangeTypes(tool.BatchTool, ManagedWindow.ManagedWindow):
 
     def __init__(self, dbstate, uistate, options_class, name, callback=None):
 
-        tool.BatchTool.__init__(self, dbstate, options_class, name)
+        tool.BatchTool.__init__(self, dbstate, uistate, options_class, name)
         if self.fail:
             return
 
