@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExtractCity.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id: ExtractCity.py 22894 2013-08-21 14:41:12Z vassilii $
 
 """Tools/Database Processing/Extract Place Data from a Place Title"""
 
@@ -417,7 +417,7 @@ class ExtractCity(tool.BatchTool, ManagedWindow.ManagedWindow):
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self.__class__)
         self.set_window(gtk.Window(), gtk.Label(), '')
 
-        tool.BatchTool.__init__(self, dbstate, options_class, name)
+        tool.BatchTool.__init__(self, dbstate, uistate, options_class, name)
 
         if not self.fail:
             uistate.set_busy_cursor(True)
