@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: OwnerEditor.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id: OwnerEditor.py 19753 2012-06-04 00:55:10Z jralls $
 
 """Tools/Database Processing/Edit Database Owner Information"""
 
@@ -46,6 +46,7 @@ import ManagedWindow
 from gui.plug import tool
 from gen.ggettext import sgettext as _
 from glade import Glade
+import gui.utils
 
 #-------------------------------------------------------------------------
 #
@@ -154,7 +155,7 @@ class OwnerEditor(tool.Tool, ManagedWindow.ManagedWindow):
 
     def on_button_press_event(self, obj, event):
         """Shows popup-menu for db <-> preferences copying"""
-        if event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS:
+        if gui.utils.is_right_click(event):
             self.menu.popup(None,None,None,0,0)
 
     def build_menu_names(self, obj):
