@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: ReorderIds.py 22894 2013-08-21 14:41:12Z vassilii $
 
 """
 Change id IDs of all the elements in the database to conform to the
@@ -57,7 +57,7 @@ _parseformat = re.compile('.*%(\d+)[^\d]+')
 #-------------------------------------------------------------------------
 class ReorderIds(tool.BatchTool):
     def __init__(self, dbstate, uistate, options_class, name, callback=None):
-        tool.BatchTool.__init__(self, dbstate, options_class, name)
+        tool.BatchTool.__init__(self, dbstate, uistate, options_class, name)
         if self.fail:
             return
 
