@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: citationtreeview.py 23141 2013-09-16 21:38:16Z kulath $
 
 """
 Citation Tree View (or Source tree view).
@@ -87,7 +87,7 @@ class CitationTreeView(ListView):
     COL_SRC_PINFO      =  7
     # name of the columns
     COLUMN_NAMES = [
-        _('Title or Page'),
+        _('Source: Title or Citation: Volume/Page'),
         _('ID'),
         _('Date'),
         _('Confidence'),
@@ -154,20 +154,25 @@ class CitationTreeView(ListView):
 
         self.additional_uis.append(self.additional_ui())
 
+    # Override change_active from NavigationView, so that only Citations can be
+    # put in the history list for the CitationTreeView
+    def change_active(self, handle):
+        if self.dbstate.db.get_citation_from_handle(handle):
+            super(CitationTreeView, self).change_active(handle)
+        else:
+            # FIXME: See http://www.gramps-project.org/bugs/view.php?id=6352 a
+            # more comprehensive solution is needed in the long term. See also
+            # add in Bookmarks.CitationBookmarks
+            pass
+    
     def setup_filter(self):
         """
         Override the setup of the default Search Bar in listview, so that only
-        the searchable source fields are shown. This includes renaming the
-        'Title or Page' search to 'Title'
+        the searchable source fields are shown.
         """
-        def name(i):
-            if i == 0:
-                return _('Title')
-            else:
-                return self.colinfo[i]
              
         self.search_bar.setup_filter(
-            [(name(pair[1]), pair[1], pair[1] in self.exact_search())
+            [(self.colinfo[pair[1]], pair[1], pair[1] in self.exact_search())
                 for pair in self.column_order() if pair[0] and 
                                 pair[1] in self.COLUMN_FILTERABLE])
 
@@ -576,7 +581,7 @@ class CitationTreeView(ListView):
         """
         Define the default gramplets for the sidebar and bottombar.
         """
-        return (("Source Filter",),
+        return (("Citation Filter",),
                 ("Citation Gallery",
                  "Citation Notes",
                  "Citation Backlinks"))
