@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: fanchartview.py 19753 2012-06-04 00:55:10Z jralls $
+# $Id: fanchartview.py 22532 2013-06-20 09:39:03Z vassilii $
 
 ## Based on the paper:
 ##   http://www.cs.utah.edu/~draperg/research/fanchart/draperg_FHT08.pdf
@@ -345,13 +345,17 @@ class FanChartWidget(gtk.Widget):
         pos = start + ((stop - start) - self.text_degrees(text,radius))/2.0 + 90
         x, y, w, h = self.allocation
         cr.save()
-        # Create a PangoLayout, set the font and text 
-        # Draw the layout N_WORDS times in a circle 
-        for i in range(len(text)):
+        l = len(text)
+        # A quick hack so it works at least in some RTL scenarios
+        # CTL text will still be broken, see bug# 4571
+        ith_char_sector = (lambda i: l - i) if pango.find_base_dir(text, l) \
+                                               == pango.DIRECTION_RTL \
+                                            else lambda i: i
+        for i in range(l):
             cr.save()
             layout = self.create_pango_layout(text[i])
             layout.set_font_description(pango.FontDescription("sans 8"))
-            angle = 360.0 * i / (radius * self.degrees_per_radius) + pos
+            angle = 360.0 * ith_char_sector(i) / (radius * self.degrees_per_radius) + pos
             cr.set_source_rgb(0, 0, 0) # black 
             cr.rotate(angle * (math.pi / 180));
             # Inform Pango to re-layout the text with the new transformation
