@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geography.gpr.py 20010 2012-07-16 17:53:43Z kulath $
+# $Id: geography.gpr.py 23360 2013-10-21 19:52:35Z paul-franklin $
 
 #------------------------------------------------------------------------
 #
@@ -38,9 +38,12 @@ try :
                         osmgpsmap.__version__)
 except:
     OSMGPSMAP = False
-    import logging
-    logging.warning(_("WARNING: osmgpsmap module not loaded. "
-                      "Geography functionality will not be available."))
+    import config
+    if not config.get('interface.ignore-osmgpsmap'):
+        from QuestionDialog import MessageHideDialog
+        title = _("OsmGpsMap module not loaded.")
+        message = _("Geography functionality will not be available.")
+        MessageHideDialog(title, message, 'interface.ignore-osmgpsmap')
 
 if OSMGPSMAP:
     # Load the view only if osmgpsmap library is present.
