@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geoplaces.py 19847 2012-06-16 09:16:55Z noirauds $
+# $Id: geoplaces.py 23066 2013-09-09 15:34:53Z noirauds $
 
 """
 Geography for places
@@ -113,7 +113,7 @@ class GeoPlaces(GeoGraphyView):
     """
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
-        GeoGraphyView.__init__(self, _('Places places map'),
+        GeoGraphyView.__init__(self, _('Places map'),
                                       pdata, dbstate, uistate, 
                                       dbstate.db.get_place_bookmarks(), 
                                       Bookmarks.PlaceBookmarks,
