@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: relview.py 18088 2011-08-30 18:35:29Z nick-h $
+# $Id: relview.py 18657 2011-12-28 21:45:56Z m_d_n $
 
 """
 Relationship View
@@ -146,7 +146,7 @@ class RelationshipView(NavigationView):
         uistate.connect('nameformat-changed', self.build_tree)
         self.redrawing = False
 
-        self.color = gtk.TextView().style.white
+        self.color = self.uistate.window.style.light[gtk.STATE_NORMAL]
         self.child = None
         self.old_handle = None
 
