@@ -3,6 +3,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2009 Benny Malengier
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: view.gpr.py 15029 2010-04-04 18:16:03Z nick-h $
+# $Id: view.gpr.py 18798 2012-01-30 10:49:41Z romjerome $
 
 #------------------------------------------------------------------------
 #
@@ -32,7 +33,7 @@ id    = 'eventview',
 name  = _("Event View"),
 description =  _("The view showing all the events"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'eventview.py',
 authors = [u"The Gramps project"],
@@ -47,7 +48,7 @@ id    = 'familyview',
 name  = _("Family View"),
 description =  _("The view showing all families"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'familyview.py',
 authors = [u"The Gramps project"],
@@ -60,9 +61,9 @@ order = START,
 register(VIEW, 
 id    = 'grampletview',
 name  = _("Gramplet View"),
-description =  _("The view allowing to see Gramplets"),
+description =  _("The view showing Gramplets"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'grampletview.py',
 authors = [u"The Gramps project"],
@@ -77,7 +78,7 @@ id    = 'mediaview',
 name  = _("Media View"),
 description =  _("The view showing all the media objects"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'mediaview.py',
 authors = [u"The Gramps project"],
@@ -92,7 +93,7 @@ id    = 'noteview',
 name  = _("Note View"),
 description =  _("The view showing all the notes"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'noteview.py',
 authors = [u"The Gramps project"],
@@ -107,7 +108,7 @@ id    = 'relview',
 name  = _("Relationship View"),
 description =  _("The view showing all relationships of the selected person"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'relview.py',
 authors = [u"The Gramps project"],
@@ -122,7 +123,7 @@ id    = 'pedigreeview',
 name  = _("Pedigree View"),
 description =  _("The view showing an ancestor pedigree of the selected person"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'pedigreeview.py',
 authors = [u"The Gramps project"],
@@ -138,7 +139,7 @@ id    = 'personview',
 name  = _("Person Tree View"),
 description =  _("The view showing all people in the family tree"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'persontreeview.py',
 authors = [u"The Gramps project"],
@@ -155,7 +156,7 @@ name  = _("Person View"),
 description =  _("The view showing all people in the family tree"
                  " in a flat list"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'personlistview.py',
 authors = [u"The Gramps project"],
@@ -171,7 +172,7 @@ id    = 'placelistview',
 name  = _("Place View"),
 description =  _("The view showing all the places of the family tree"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'placelistview.py',
 authors = [u"The Gramps project"],
@@ -187,7 +188,7 @@ id    = 'repoview',
 name  = _("Repository View"),
 description =  _("The view showing all the repositories"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'repoview.py',
 authors = [u"The Gramps project"],
@@ -202,7 +203,7 @@ id    = 'sourceview',
 name  = _("Source View"),
 description =  _("The view showing all the sources"),
 version = '1.0',
-gramps_target_version = '3.3',
+gramps_target_version = '3.4',
 status = STABLE,
 fname = 'sourceview.py',
 authors = [u"The Gramps project"],
@@ -210,4 +211,35 @@ authors_email = ["http://gramps-project.org"],
 category = ("Sources", _("Sources")),
 viewclass = 'SourceView',
 order = START,
+stock_icon = 'gramps-tree-list',
+  )
+
+register(VIEW, 
+id    = 'citationlistview',
+name  = _("Citation View"),
+description =  _("The view showing all the citations"),
+version = '1.0',
+gramps_target_version = '3.4',
+status = STABLE,
+fname = 'citationlistview.py',
+authors = [u"The Gramps project"],
+authors_email = ["http://gramps-project.org"],
+category = ("Citations", _("Citations")),
+viewclass = 'CitationListView',
+order = START,
+  )
+
+register(VIEW, 
+id = 'citationtreeview',
+name = _("Citation Tree View"),
+description =  _("A view displaying citations and sources in a tree format."),
+version = '1.0',
+gramps_target_version = '3.4',
+status = STABLE,
+fname = 'citationtreeview.py',
+authors = [u"Tim G L Lyons", u"Nick Hall"],
+authors_email = [""],
+category = ("Sources", _("Sources")),
+viewclass = 'CitationTreeView',
+stock_icon = 'gramps-tree-select',
   )
