@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: WebCal.py 21304 2013-02-05 18:06:02Z kulath $
+# $Id: WebCal.py 23306 2013-10-11 11:46:06Z dsblank $
 
 """
 Web Calendar generator.
@@ -69,6 +69,8 @@ from libhtml import Html
 from libhtmlconst import _CHARACTER_SETS, _CC, _COPY_OPTIONS
 from gui.pluginmanager import GuiPluginManager
 
+from gen.lib.date import gregorian
+
 # import styled notes from
 # src/plugins/lib/libhtmlbackend.py
 from libhtmlbackend import HtmlBackend
@@ -559,7 +561,7 @@ class WebCalReport(Report):
                     elif url_fname == 'fullyearlinked':
                         myTitle = _('Full year at a Glance')
                     else:
-	                 myTitle = _(url_fname)
+                        myTitle = _(url_fname)
                     hyper = Html("a", nav_text, href = url, name = url_fname, title = myTitle)
 
                     if check_cs:
@@ -1084,6 +1086,7 @@ class WebCalReport(Report):
 
             # determine birthday information???
             if (self.birthday and birth_date is not gen.lib.Date.EMPTY and birth_date.is_valid()):
+                birth_date = gregorian(birth_date)
 
                 year = birth_date.get_year() or this_year
                 month = birth_date.get_month()
@@ -1147,6 +1150,7 @@ class WebCalReport(Report):
                         if marriage_event:
                             event_date = marriage_event.get_date_object()
                             if event_date is not gen.lib.Date.EMPTY and event_date.is_valid():
+                                event_date = gregorian(event_date)
                                 year = event_date.get_year()
                                 month = event_date.get_month()
                                 day = event_date.get_day()
@@ -1680,7 +1684,7 @@ def get_day_list(event_date, holiday_list, bday_anniv_list):
 
         # number of years for birthday, ex: 10 years
         age_str = event_date - date
-        age_str.format(precision = 1)
+        age_str.format(precision = 1, as_age=False)
 
         # a birthday
         if event == 'Birthday':
