@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: webstuff.py 20794 2012-12-18 22:53:22Z kulath $
 
 #------------------------------------------------
 #    python modules
@@ -147,6 +147,10 @@ def load_on_reg(dbstate, uistate, plugin):
         # no style sheet option
         ["No style sheet",1, _("No style sheet"),    [],    None, [], [] ],
 
+        # Document image
+        ["Document", 0, "Document",
+         path_img("document.png"), None, [], [] ],
+
         # all other images for use in NarrativeWeb
         ['All Images', 0, 'All Images', None, None, 
          [path_img("blank.gif"),
